@@ -592,7 +592,7 @@ void KAccessApp::createDialogContents() {
       lay->setSpacing(KDialog::spacingHint());
 
       QLabel *label1 = new QLabel( contents);
-      QPixmap pixmap = KIconLoader::global()->loadIcon("dialog-warning", K3Icon::NoGroup, K3Icon::SizeMedium, K3Icon::DefaultState, QStringList(), 0, true);
+      QPixmap pixmap = KIconLoader::global()->loadIcon("dialog-warning", KIconLoader::NoGroup, KIconLoader::SizeMedium, KIconLoader::DefaultState, QStringList(), 0, true);
       if (pixmap.isNull())
          pixmap = QMessageBox::standardIcon(QMessageBox::Warning);
       label1->setPixmap(pixmap);
