@@ -164,7 +164,7 @@ void FontUseItem::setDefault()
 
 void FontUseItem::readFont()
 {
-  KConfigBase *config;
+  KConfig *config;
 
   bool deleteme = false;
   if (_rcfile.isEmpty())
@@ -183,11 +183,11 @@ void FontUseItem::readFont()
 
 void FontUseItem::writeFont()
 {
-  KConfigBase *config;
+  KConfig *config;
 
   if (_rcfile.isEmpty()) {
     config = KGlobal::config().data();
-    KConfigGroup(config, _rcgroup).writeEntry(_rckey, font(), KConfigBase::Normal|KConfigBase::Global);
+    KConfigGroup(config, _rcgroup).writeEntry(_rckey, font(), KConfig::Normal|KConfig::Global);
   } else {
     config = new KConfig(KStandardDirs::locateLocal("config", _rcfile));
     KConfigGroup(config, _rcgroup).writeEntry(_rckey, font());
@@ -328,7 +328,7 @@ bool FontAASettings::load()
 
   if(!xft.getHintStyle(hStyle) || KXftConfig::Hint::NotSet==hStyle)
   {
-    KConfig kglobals("kdeglobals", KConfig::NoGlobals);
+    KConfig kglobals("kdeglobals", KConfig::CascadeConfig);
 
     hStyle=KXftConfig::Hint::Medium;
     xft.setHintStyle(hStyle);
@@ -348,7 +348,7 @@ bool FontAASettings::load()
 bool FontAASettings::save( bool useAA )
 {
   KXftConfig   xft(KXftConfig::constStyleSettings);
-  KConfig      kglobals("kdeglobals", KConfig::NoGlobals);
+  KConfig      kglobals("kdeglobals", KConfig::CascadeConfig);
   KConfigGroup grp(&kglobals, "General");
 
   xft.setAntiAliasing( useAA );
@@ -600,7 +600,7 @@ KFonts::KFonts(QWidget *parent, const QVariantList &args)
     fontUseList.append(i);
     connect(i, SIGNAL(fontSelected(const QFont &)), SLOT(fontSelected()));
 
-    QLabel * fontUse = new QLabel(name+':', this);
+    QLabel * fontUse = new QLabel(i18nc("Font role", "%1: ", name), this);
     fontUse->setWhatsThis( *quickHelpIt++);
 
     fontUseLayout->addWidget(fontUse, count, 0);
@@ -629,9 +629,9 @@ KFonts::KFonts(QWidget *parent, const QVariantList &args)
    label = new QLabel( i18n( "Use a&nti-aliasing:" ), this );
    lay->addWidget( label, 0, 0 );
    cbAA = new QComboBox( this );
-   cbAA->insertItem( AAEnabled, i18n( "Enabled" )); // change AASetting type if order changes
-   cbAA->insertItem( AASystem, i18n( "System settings" ));
-   cbAA->insertItem( AADisabled, i18n( "Disabled" ));
+   cbAA->insertItem( AAEnabled, i18nc( "Use anti-aliasing", "Enabled" )); // change AASetting type if order changes
+   cbAA->insertItem( AASystem, i18nc( "Use anti-aliasing", "System settings" ));
+   cbAA->insertItem( AADisabled, i18nc( "Use annti-aliasing", "Disabled" ));
    cbAA->setWhatsThis( i18n("If this option is selected, KDE will smooth the edges of curves in "
                               "fonts."));
    aaSettingsButton = new QPushButton( i18n( "Configure..." ), this);
@@ -645,7 +645,7 @@ KFonts::KFonts(QWidget *parent, const QVariantList &args)
    lay->addWidget( label, 1, 0 );
    comboForceDpi = new QComboBox( this );
    label->setBuddy( comboForceDpi );
-   comboForceDpi->insertItem( DPINone, i18n( "Disabled" )); // change DPISetti ng type if order changes
+   comboForceDpi->insertItem( DPINone, i18nc("Force fonts DPI", "Disabled" )); // change DPISetti ng type if order changes
    comboForceDpi->insertItem( DPI96, i18n( "96 DPI" ));
    comboForceDpi->insertItem( DPI120, i18n( "120 DPI" ));
    QString whatsthis = i18n(
@@ -765,7 +765,7 @@ void KFonts::save()
 
   // KDE-1.x support
   {
-  KConfig config( QDir::homePath() + "/.kderc", KConfig::OnlyLocal);
+  KConfig config( QDir::homePath() + "/.kderc", KConfig::SimpleConfig);
   KConfigGroup grp(&config, "General");
 
   for(it=fontUseList.begin(); it!=end; ++it) {
