@@ -157,19 +157,18 @@ MouseConfig::MouseConfig(QWidget *parent, const QVariantList &args)
          " must be paused over the icon before it is selected.");
     tab1->slAutoSelect->setWhatsThis( wtstr );
 
-    wtstr = i18n("Show feedback when clicking an icon");
-    tab1->cbVisualActivate->setWhatsThis( wtstr );
-
     connect(tab1->slAutoSelect, SIGNAL(valueChanged(int)), this, SLOT(changed()));
-    connect(tab1->cbVisualActivate, SIGNAL(clicked()), this, SLOT(changed()));
 
     connect(tab1->cb_pointershape, SIGNAL(clicked()), this, SLOT(changed()));
 
     connect(tab1->singleClick, SIGNAL(clicked()), this, SLOT(changed()));
     connect(tab1->singleClick, SIGNAL(clicked()), this, SLOT(slotClick()));
+    connect(tab1->singleClick, SIGNAL(clicked()), this, SLOT(slotSmartSliderEnabling()));
 
     connect( tab1->doubleClick, SIGNAL( clicked() ), this, SLOT( slotClick() ) );
     connect( tab1->cbAutoSelect, SIGNAL( clicked() ), this, SLOT( slotClick() ) );
+    connect(tab1->cbAutoSelect, SIGNAL(clicked()), this, SLOT(slotSmartSliderEnabling()));
+
 
     // Only allow setting reversing scroll polarity if we have scroll buttons
     unsigned char map[20];
@@ -530,7 +529,6 @@ void MouseConfig::load()
      tab1->slAutoSelect->setValue( 0 );
   else
      tab1->slAutoSelect->setValue( settings->autoSelectDelay );
-  tab1->cbVisualActivate->setChecked( settings->visualActivate );
   slotClick();
 
 
@@ -578,7 +576,6 @@ void MouseConfig::save()
   settings->wheelScrollLines = wheelScrollLines->value();
   settings->singleClick = !tab1->doubleClick->isChecked();
   settings->autoSelectDelay = tab1->cbAutoSelect->isChecked()? tab1->slAutoSelect->value():-1;
-  settings->visualActivate = tab1->cbVisualActivate->isChecked();
 //  settings->changeCursor = tab1->singleClick->isChecked();
   settings->changeCursor = tab1->cb_pointershape->isChecked();
   settings->reverseScrollPolarity = tab1->cbScrollPolarity->isChecked();
@@ -628,7 +625,6 @@ void MouseConfig::defaults()
     tab1->cbAutoSelect->setChecked( KDE_DEFAULT_AUTOSELECTDELAY != -1 );
     tab1->slAutoSelect->setValue( KDE_DEFAULT_AUTOSELECTDELAY == -1 ? 50 : KDE_DEFAULT_AUTOSELECTDELAY );
     tab1->singleClick->setChecked( KDE_DEFAULT_SINGLECLICK );
-    tab1->cbVisualActivate->setChecked( KDE_DEFAULT_VISUAL_ACTIVATE );
     tab1->cb_pointershape->setChecked(KDE_DEFAULT_CHANGECURSOR);
     slotClick();
 
@@ -746,7 +742,6 @@ void MouseSettings::load(KConfig *config)
 
   singleClick = group.readEntry("SingleClick", KDE_DEFAULT_SINGLECLICK);
   autoSelectDelay = group.readEntry("AutoSelectDelay", KDE_DEFAULT_AUTOSELECTDELAY);
-  visualActivate = group.readEntry("VisualActivate", KDE_DEFAULT_VISUAL_ACTIVATE);
   changeCursor = group.readEntry("ChangeCursor", KDE_DEFAULT_CHANGECURSOR);
 }
 
@@ -852,14 +847,13 @@ void MouseSettings::save(KConfig *config)
   group.writeEntry( "ReverseScrollPolarity", reverseScrollPolarity );
 
   group = config->group("KDE");
-  group.writeEntry("DoubleClickInterval", doubleClickInterval, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("StartDragTime", dragStartTime, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("StartDragDist", dragStartDist, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("WheelScrollLines", wheelScrollLines, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("SingleClick", singleClick, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("AutoSelectDelay", autoSelectDelay, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("VisualActivate", visualActivate, KConfigBase::Persistent|KConfigBase::Global);
-  group.writeEntry("ChangeCursor", changeCursor,KConfigBase::Persistent|KConfigBase::Global);
+  group.writeEntry("DoubleClickInterval", doubleClickInterval, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("StartDragTime", dragStartTime, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("StartDragDist", dragStartDist, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("WheelScrollLines", wheelScrollLines, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("SingleClick", singleClick, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("AutoSelectDelay", autoSelectDelay, KConfig::Persistent|KConfig::Global);
+  group.writeEntry("ChangeCursor", changeCursor,KConfig::Persistent|KConfig::Global);
   // This iterates through the various Logitech mice, if we have support.
 #ifdef HAVE_LIBUSB
   LogitechMouse *logitechMouse;
@@ -876,4 +870,13 @@ void MouseConfig::slotScrollPolarityChanged()
   settings->m_handedNeedsApply = true;
 }
 
+void MouseConfig::slotSmartSliderEnabling()
+{
+  bool enabled = tab1->singleClick->isChecked() ? tab1->cbAutoSelect->isChecked() : false;
+  tab1->lDelay->setEnabled(enabled);
+  tab1->slAutoSelect->setEnabled(enabled);
+  tab1->lb_short->setEnabled(enabled);
+  tab1->lb_long->setEnabled(enabled);
+}
+
 #include "mouse.moc"
