@@ -91,10 +91,10 @@ static void addFont(CFontItem *font, CJobRunner::ItemList &urls, QStringList &fo
     }
 }
 
-static QString getName(const KFileItem *item)
+static QString getName(const KFileItem &item)
 {
-    return item
-        ? item->entry().stringValue(KIO::UDSEntry::UDS_NAME)
+    return !item.isNull()
+        ? item.entry().stringValue(KIO::UDSEntry::UDS_NAME)
         : QString();
 }
 
@@ -381,21 +381,16 @@ inline bool isSysFolder(const QString &sect)
     return i18n(KFI_KIO_FONTS_SYS)==sect || KFI_KIO_FONTS_SYS==sect;
 }
 
-CFontItem::CFontItem(CFontModelItem *p, const KFileItem *item, const QString &style)
+CFontItem::CFontItem(CFontModelItem *p, const KFileItem &item, const QString &style)
          : CFontModelItem(p),
            itsItem(item),
            itsStyle(style),
            itsPixmap(NULL)
 {
     const KIO::UDSEntry &udsEntry(entry());
-    int                 weight,
-                        width,
-                        slant;
 
     updateStatus();
     itsName=udsEntry.stringValue(KIO::UDSEntry::UDS_NAME);
-    FC::decomposeStyleVal(FC::createStyleVal(itsName), weight, width, slant);
-    itsDisplayStyleInfo=(weight<<16)+(slant<<8)+(width);
     itsFileName=udsEntry.stringValue((uint)UDS_EXTRA_FILE_NAME);
     itsStyleInfo=udsEntry.numberValue((uint)UDS_EXTRA_FC_STYLE);
     itsIndex=Misc::getIntQueryVal(KUrl(udsEntry.stringValue((uint)KIO::UDSEntry::UDS_URL)),
@@ -403,19 +398,18 @@ CFontItem::CFontItem(CFontModelItem *p, const KFileItem *item, const QString &st
     itsWritingSystems=udsEntry.numberValue((uint)UDS_EXTRA_WRITING_SYSTEMS);
     QString mime(mimetype());
 
-//    itsBitmap="application/x-font-pcf"==mime || "application/x-font-bdf"==mime;
-    itsBitmap="application/x-font-ttf"!=mime && "application/x-font-otf"!=mime &&
-              "application/x-font-type1"!=mime;
+    itsBitmap="application/x-font-pcf"==mime || "application/x-font-bdf"==mime;
 
     if(!Misc::root())
         setIsSystem(isSysFolder(url().path().section('/', 1, 1)));
 
     QString files=udsEntry.stringValue((uint)UDS_EXTRA_FILE_LIST);
 
-    if(files.isEmpty())
-        itsFiles.append(CDisabledFonts::TFile(itsFileName));
-    else
+    if(!files.isEmpty())
         itsFiles.fromString(files);
+
+    itsFiles.prepend(CDisabledFonts::TFile(itsFileName, itsIndex,
+                                           udsEntry.stringValue((uint)UDS_EXTRA_FOUNDRY)));
 }
 
 void CFontItem::touchThumbnail()
@@ -478,7 +472,7 @@ void CFamilyItem::touchThumbnail()
         itsRegularFont->touchThumbnail();
 }
 
-CFontItem * CFamilyItem::findFont(const KFileItem *i)
+CFontItem * CFamilyItem::findFont(const KFileItem &i)
 {
     QList<CFontItem *>::ConstIterator fIt(itsFonts.begin()),
                                       fEnd(itsFonts.end());
@@ -602,7 +596,7 @@ bool CFamilyItem::updateStatus()
 
 bool CFamilyItem::updateRegularFont(CFontItem *font)
 {
-    static const int constRegular=(FC_WEIGHT_REGULAR<<16)+(FC_SLANT_ROMAN<<8)+KFI_FC_WIDTH_NORMAL;
+    static const quint32 constRegular=FC::createStyleVal(FC_WEIGHT_REGULAR, KFI_FC_WIDTH_NORMAL, FC_SLANT_ROMAN);
 
     CFontItem *oldFont(itsRegularFont);
     bool       root(Misc::root());
@@ -611,8 +605,8 @@ bool CFamilyItem::updateRegularFont(CFontItem *font)
     {
         if(itsRegularFont)
         {
-            int regDiff=abs(itsRegularFont->displayStyleInfo()-constRegular),
-                fontDiff=abs(font->displayStyleInfo()-constRegular);
+            int regDiff=abs(itsRegularFont->styleInfo()-constRegular),
+                fontDiff=abs(font->styleInfo()-constRegular);
 
             if(fontDiff<regDiff)
                 itsRegularFont=font;
@@ -624,12 +618,13 @@ bool CFamilyItem::updateRegularFont(CFontItem *font)
     {
         QList<CFontItem *>::ConstIterator it(itsFonts.begin()),
                                           end(itsFonts.end());
-        int                               current=0x0FFFFFFF;
+        quint32                           current=0x0FFFFFFF;
 
         for(; it!=end; ++it)
             if(usable(*it, root))
             {
-                int diff=abs((*it)->displayStyleInfo()-constRegular);
+                quint32 diff=abs((*it)->styleInfo()-constRegular);
+
                 if(diff<current)
                 {
                     itsRegularFont=(*it);
@@ -915,6 +910,8 @@ void CFontList::listingCompleted()
 
 void CFontList::newItems(const KFileItemList &items)
 {
+    emit layoutAboutToBeChanged();
+
 #ifdef KFI_FONTLIST_DEBUG
     kDebug() << "************** newItems " << items.count();
 
@@ -943,6 +940,8 @@ void CFontList::clearItems()
 
 void CFontList::refreshItems(const KFileItemList &items)
 {
+    emit layoutAboutToBeChanged();
+
 #ifdef KFI_FONTLIST_DEBUG
     kDebug() << "************** refreshItems " << items.count();
 
@@ -982,6 +981,8 @@ void CFontList::refreshItems(const KFileItemList &items)
 
 void CFontList::deleteItems(const KFileItemList &items)
 {
+    emit layoutAboutToBeChanged();
+
 #ifdef KFI_FONTLIST_DEBUG
     kDebug() << "************** deleteItems " << items.count();
 #endif
@@ -1008,12 +1009,12 @@ void CFontList::deleteItems(const KFileItemList &items)
     emit layoutChanged();
 }
 
-void CFontList::addItem(const KFileItem *item)
+void CFontList::addItem(const KFileItem &item)
 {
     CFontItem *font=findFont(item);
 
 #ifdef KFI_FONTLIST_DEBUG
-    kDebug() << "************** addItem " << item->url();
+    kDebug() << "************** addItem " << item.url();
 #endif
     if(!font)
     {
@@ -1061,7 +1062,7 @@ CFamilyItem * CFontList::findFamily(const QString &familyName, bool create)
     return fam;
 }
 
-CFontItem * CFontList::findFont(const KFileItem *item)
+CFontItem * CFontList::findFont(const KFileItem &item)
 {
     return itsFonts.contains(item)
             ? itsFonts[item]
@@ -1095,7 +1096,7 @@ CFontListSortFilterProxy::CFontListSortFilterProxy(QObject *parent, QAbstractIte
     setSourceModel(model);
     setSortCaseSensitivity(Qt::CaseInsensitive);
     setFilterKeyColumn(0);
-    setDynamicSortFilter(true);
+    setDynamicSortFilter(false);
     itsTimer=new QTimer(this);
     connect(itsTimer, SIGNAL(timeout()), SLOT(timeout()));
     itsTimer->setSingleShot(true);
@@ -1210,14 +1211,14 @@ QVariant CFontListSortFilterProxy::data(const QModelIndex &idx, int role) const
                     case COL_FONT:
                         return SmallIcon(fam->icon(), 0,
                                          CFamilyItem::ENABLED==fam->status()
-                                            ? K3Icon::DefaultState
-                                            : K3Icon::DisabledState);
+                                            ? KIconLoader::DefaultState
+                                            : KIconLoader::DisabledState);
                         break;
                     case COL_STATUS:
                         switch(fam->status())
                         {
                             case CFamilyItem::PARTIAL:
-                                return SmallIcon("dialog-ok", 0, K3Icon::DisabledState);
+                                return SmallIcon("dialog-ok", 0, KIconLoader::DisabledState);
                             case CFamilyItem::ENABLED:
                                 return SmallIcon("dialog-ok");
                             case CFamilyItem::DISABLED:
@@ -1363,11 +1364,11 @@ bool CFontListSortFilterProxy::lessThan(const QModelIndex &left, const QModelInd
             {
                 if(lfi->isEnabled()<rfi->isEnabled() ||
                   (lfi->isEnabled()==rfi->isEnabled() &&
-                   lfi->displayStyleInfo()<rfi->displayStyleInfo()))
+                   lfi->styleInfo()<rfi->styleInfo()))
                     return true;
             }
             else
-                if(lfi->displayStyleInfo()<rfi->displayStyleInfo())
+                if(lfi->styleInfo()<rfi->styleInfo())
                     return true;
         }
         else
@@ -2085,7 +2086,7 @@ void CFontListView::startDrag(Qt::DropActions supportedActions)
         }
 
         QPoint  hotspot;
-        QPixmap pix(DesktopIcon(icon, K3Icon::SizeMedium));
+        QPixmap pix(DesktopIcon(icon, KIconLoader::SizeMedium));
 
         hotspot.setX(0); // pix.width()/2);
         hotspot.setY(0); // pix.height()/2);
