@@ -257,7 +257,7 @@ bool CDisabledFonts::refresh()
 }
 
 //
-// Dont always lock during a load, as we may be trying to read global file (but not as root),
+// Do not always lock during a load, as we may be trying to read global file (but not as root),
 // or this load might be being called within the save() - so cant lock as is already!
 void CDisabledFonts::load(bool lock)
 {
@@ -382,13 +382,16 @@ bool CDisabledFonts::TFile::load(QDomElement &elem)
     return false;
 }
 
-QString CDisabledFonts::TFileList::toString() const
+QString CDisabledFonts::TFileList::toString(bool skipFirst) const
 {
     QString       s;
     QTextStream   str(&s, QIODevice::WriteOnly);
     ConstIterator it(begin()),
                   e(end());
 
+    if(skipFirst && it!=e)
+        ++it;
+
     for(; it!=e; ++it)
         str << (*it).path << endl
             << (*it).foundry << endl
