@@ -1,14 +1,21 @@
-//
-// C++ Interface: layoutmap
-//
-// Description: 
-//
-//
-// Author: Andriy Rysin <rysin@kde.org>, (C) 2006
-//
-// Copyright: See COPYING file that comes with this distribution
-//
-//
+/*
+ *  Copyright (C) 2006 Andriy Rysin (rysin@kde.org)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 
 #ifndef __LAYOUTMAP_H
 #define __LAYOUTMAP_H
@@ -49,12 +56,14 @@ private:
 	
 	const KxkbConfig& m_kxkbConfig;
 	WId m_currentWinId;
+	int m_currentDesktop;
 	QString m_currentWinClass; // only for SWITCH_POLICY_WIN_CLASS
 	
 	void initLayoutQueue(LayoutQueue& layoutQueue);
-	LayoutQueue& getCurrentLayoutQueue(WId winId);
-	LayoutQueue& getCurrentLayoutQueueInternal(WId winId);
+	LayoutQueue& getCurrentLayoutQueue();
+	LayoutQueue& getCurrentLayoutQueueInternal();
 	void clearMaps();
+	QString getOwner();
 };
 
 #endif
