@@ -1,3 +1,21 @@
+/*
+ *  Copyright (C) 2006 Andriy Rysin (rysin@kde.org)
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 #ifndef X11HELPER_H_
 #define X11HELPER_H_
 
@@ -22,10 +40,6 @@ struct RulesInfo {
 	QHash<QString, XkbOptionGroup> optionGroups;
 };
 
-struct OldLayouts {
-	QStringList oldLayouts;
-	QStringList nonLatinLayouts;
-};
 
 class X11Helper
 {
@@ -36,7 +50,6 @@ public:
 
 	static QString getWindowClass(WId winId, Display* dpy);
 
-	static bool areSingleGroupsSupported() { return true; } // assume not ancient xorg
 #ifndef HAVE_XKLAVIER
 	/**
 	 * Tries to find X11 xkb config dir
@@ -45,7 +58,6 @@ public:
 	static const QString findXkbRulesFile(const QString &x11Dir, Display* dpy);
 	static QStringList* getVariants(const QString& layout, const QString& x11Dir);
 	static RulesInfo* loadRules(const QString& rulesFile, bool layoutsOnly=false);
-	static OldLayouts* loadOldLayouts(const QString& rulesFile);
 private:
 
 	static XkbOptionGroup createMissingGroup(const QString& groupName);
