@@ -60,18 +60,20 @@
 
 /**** DLL Interface for kcontrol ****/
 
+#include <kpluginfactory.h>
+#include <kpluginloader.h>
+#include <KLibLoader>
 
-#include <kgenericfactory.h>
+K_PLUGIN_FACTORY(KCMStyleFactory, registerPlugin<KCMStyle>();)
+K_EXPORT_PLUGIN(KCMStyleFactory("kcmstyle"))
 
-typedef KGenericFactory<KCMStyle, QWidget> KCMStyleFactory;
-K_EXPORT_COMPONENT_FACTORY( kcm_style, KCMStyleFactory("kcmstyle") )
 
 extern "C"
 {
     KDE_EXPORT void kcminit_style()
     {
         uint flags = KRdbExportQtSettings | KRdbExportQtColors | KRdbExportXftSettings;
-        KConfig _config( "kcmdisplayrc", KConfig::NoGlobals  );
+        KConfig _config( "kcmdisplayrc", KConfig::CascadeConfig  );
         KConfigGroup config(&_config, "X11");
 
         // This key is written by the "colors" module.
@@ -141,7 +143,7 @@ public:
 };
 
 
-KCMStyle::KCMStyle( QWidget* parent, const QStringList& )
+KCMStyle::KCMStyle( QWidget* parent, const QVariantList& )
 	: KCModule( KCMStyleFactory::componentData(), parent ), appliedStyle(NULL)
 {
     setQuickHelp( i18n("<h1>Style</h1>"
@@ -437,27 +439,22 @@ void KCMStyle::styleSpecificConfig()
 {
 	QString libname = styleEntries[currentStyle()]->configPage;
 
-	// Use KLibLoader to get the library, handling
-	// any errors that arise
-	KLibLoader* loader = KLibLoader::self();
-
-	KLibrary* library = loader->library( libname );
-	if (!library)
-	{
+    KLibrary library(libname, KCMStyleFactory::componentData());
+    if (!library.load()) {
 		KMessageBox::detailedError(this,
 			i18n("There was an error loading the configuration dialog for this style."),
-			loader->lastErrorMessage(),
+            library.errorString(),
 			i18n("Unable to Load Dialog"));
 		return;
 	}
 
-        KLibrary::void_function_ptr allocPtr = library->resolveFunction("allocate_kstyle_config");
+    KLibrary::void_function_ptr allocPtr = library.resolveFunction("allocate_kstyle_config");
 
 	if (!allocPtr)
 	{
 		KMessageBox::detailedError(this,
 			i18n("There was an error loading the configuration dialog for this style."),
-			loader->lastErrorMessage(),
+            library.errorString(),
 			i18n("Unable to Load Dialog"));
 		return;
 	}
@@ -499,7 +496,7 @@ void KCMStyle::styleSpecificConfig()
 
 void KCMStyle::load()
 {
-	KConfig config( "kdeglobals", KConfig::NoGlobals );
+	KConfig config( "kdeglobals", KConfig::FullConfig );
 	// Page1 - Build up the Style ListBox
 	loadStyle( config );
 
@@ -607,26 +604,26 @@ void KCMStyle::save()
 	}
 
 	// Misc page
-	config.writeEntry( "ShowIconsOnPushButtons", cbIconsOnButtons->isChecked(), KConfigBase::Normal|KConfigBase::Global);
-	config.writeEntry( "EffectNoTooltip", !cbEnableTooltips->isChecked(), KConfigBase::Normal|KConfigBase::Global);
+	config.writeEntry( "ShowIconsOnPushButtons", cbIconsOnButtons->isChecked(), KConfig::Normal|KConfig::Global);
+	config.writeEntry( "EffectNoTooltip", !cbEnableTooltips->isChecked(), KConfig::Normal|KConfig::Global);
 
-	config.changeGroup("General");
-	config.writeEntry( "widgetStyle", currentStyle() );
+    KConfigGroup generalGroup(&_config, "General");
+    generalGroup.writeEntry("widgetStyle", currentStyle());
 
-	config.changeGroup("Toolbar style");
-	config.writeEntry( "Highlighting", cbHoverButtons->isChecked(), KConfigBase::Normal|KConfigBase::Global);
-	config.writeEntry( "TransparentMoving", cbTransparentToolbars->isChecked(), KConfigBase::Normal|KConfigBase::Global);
+    KConfigGroup toolbarStyleGroup(&_config, "Toolbar style");
+    toolbarStyleGroup.writeEntry("Highlighting", cbHoverButtons->isChecked(), KConfig::Normal|KConfig::Global);
+    toolbarStyleGroup.writeEntry("TransparentMoving", cbTransparentToolbars->isChecked(), KConfig::Normal|KConfig::Global);
 	QString tbIcon;
 	switch( comboToolbarIcons->currentIndex() )
 	{
+		case 0: tbIcon = "IconOnly"; break;
 		case 1: tbIcon = "TextOnly"; break;
-		case 2: tbIcon = "IconTextRight"; break;
-		case 3: tbIcon = "IconTextBottom"; break;
-		case 0:
-		default: tbIcon = "IconOnly"; break;
+		case 2: tbIcon = "TextBesideIcon"; break;
+		default: 
+		case 3: tbIcon = "TextUnderIcon"; break;
 	}
-	config.writeEntry( "IconText", tbIcon, KConfigBase::Normal|KConfigBase::Global);
-	config.sync();
+    toolbarStyleGroup.writeEntry("ToolButtonStyle", tbIcon, KConfig::Normal|KConfig::Global);
+    _config.sync();
 
 	// Export the changes we made to qtrc, and update all qt-only
 	// applications on the fly, ensuring that we still follow the user's
@@ -634,7 +631,7 @@ void KCMStyle::save()
 	if (m_bStyleDirty | m_bEffectsDirty)	// Export only if necessary
 	{
 		uint flags = KRdbExportQtSettings;
-		KConfig _kconfig( "kcmdisplayrc", KConfig::NoGlobals  );
+		KConfig _kconfig( "kcmdisplayrc", KConfig::CascadeConfig  );
 		KConfigGroup kconfig(&_kconfig, "X11");
 		bool exportKDEColors = kconfig.readEntry("exportKDEColors", true);
 		if (exportKDEColors)
@@ -780,7 +777,7 @@ void KCMStyle::loadStyle( KConfig& config )
 														 KStandardDirs::NoDuplicates);
 	for (QStringList::iterator it = list.begin(); it != list.end(); ++it)
 	{
-		KConfig config(  *it, KConfig::OnlyLocal);
+		KConfig config(  *it, KConfig::SimpleConfig);
 		if ( !(config.hasGroup("KDE") && config.hasGroup("Misc")) )
 			continue;
 
@@ -1059,12 +1056,12 @@ void KCMStyle::loadMisc( KConfig& config )
 	cbHoverButtons->setChecked(configGroup.readEntry("Highlighting", true));
 	cbTransparentToolbars->setChecked(configGroup.readEntry("TransparentMoving", true));
 
-	QString tbIcon = configGroup.readEntry("IconText", "IconOnly");
+	QString tbIcon = configGroup.readEntry("ToolButtonStyle", "TextUnderIcon");
 	if (tbIcon == "TextOnly")
 		comboToolbarIcons->setCurrentIndex(1);
-	else if (tbIcon == "IconTextRight")
+	else if (tbIcon == "TextBesideIcon")
 		comboToolbarIcons->setCurrentIndex(2);
-	else if (tbIcon == "IconTextBottom")
+	else if (tbIcon == "TextUnderIcon")
 		comboToolbarIcons->setCurrentIndex(3);
 	else
 		comboToolbarIcons->setCurrentIndex(0);
