@@ -64,9 +64,6 @@ extern int loginrestrictions( const char *Name, const int Mode, const char *Tty,
 extern int loginfailed( const char *User, const char *Host, const char *Tty );
 extern int loginsuccess( const char *User, const char *Host, const char *Tty, char **Msg );
 #else /* USE_PAM || _AIX */
-# ifdef USESHADOW
-#  include <shadow.h>
-# endif
 # ifdef KERBEROS
 #  include <sys/param.h>
 #  include <krb.h>
@@ -80,6 +77,9 @@ extern int loginsuccess( const char *User, const char *Host, const char *Tty, ch
 /* for expiration */
 # include <time.h>
 #endif /* USE_PAM || _AIX */
+#ifdef HAVE_GETSPNAM
+# include <shadow.h>
+#endif
 
 /*
  * Session data, mostly what struct verify_info was for
@@ -352,6 +352,9 @@ static int
 isNoPassAllowed( const char *un )
 {
 	struct passwd *pw = 0;
+# ifdef HAVE_GETSPNAM /* (sic!) - not USESHADOW */
+	struct spwd *spw;
+# endif
 #else
 isNoPassAllowed( const char *un, struct passwd *pw )
 {
@@ -375,6 +378,13 @@ isNoPassAllowed( const char *un, struct passwd *pw )
 #if defined(USE_PAM) || defined(_AIX)
 			if (!(pw = getpwnam( un )))
 				return 0;
+			if (pw->pw_passwd[0] == '!' || pw->pw_passwd[0] == '*')
+				continue;
+# ifdef HAVE_GETSPNAM /* (sic!) - not USESHADOW */
+			if ((spw = getspnam( un )) &&
+			    (spw->sp_pwdp[0] == '!' || spw->sp_pwdp[0] == '*'))
+					continue;
+# endif
 #endif
 			if (pw->pw_uid)
 				return 1;
@@ -568,25 +578,31 @@ verify( GConvFunc gconv, int rootok )
 
 	if (!(p = getpwnam( curuser ))) {
 		debug( "getpwnam() failed.\n" );
+		gconv( GCONV_PASS, 0 );
 		V_RET_AUTH;
 	}
-# ifdef __linux__ /* only Linux? */
 	if (p->pw_passwd[0] == '!' || p->pw_passwd[0] == '*') {
 		debug( "account is locked\n" );
+		gconv( GCONV_PASS, 0 );
 		V_RET_AUTH;
 	}
-# endif
 
 # ifdef USESHADOW
-	if ((sp = getspnam( curuser )))
+	if ((sp = getspnam( curuser ))) {
 		p->pw_passwd = sp->sp_pwdp;
-	else
+		if (p->pw_passwd[0] == '!' || p->pw_passwd[0] == '*') {
+			debug( "account is locked\n" );
+			gconv( GCONV_PASS, 0 );
+			V_RET_AUTH;
+		}
+	} else
 		debug( "getspnam() failed: %m. Are you root?\n" );
 # endif
 
 	if (!*p->pw_passwd) {
 		if (!td->allowNullPasswd) {
 			debug( "denying user with empty password\n" );
+			gconv( GCONV_PASS, 0 );
 			V_RET_AUTH;
 		}
 		goto nplogin;
@@ -609,7 +625,7 @@ verify( GConvFunc gconv, int rootok )
 		char realm[REALM_SZ];
 
 		if (krb_get_lrealm( realm, 1 )) {
-			logError( "Can't get KerberosIV realm.\n" );
+			logError( "Cannot get KerberosIV realm.\n" );
 			V_RET_FAIL( 0 );
 		}
 
@@ -635,6 +651,8 @@ verify( GConvFunc gconv, int rootok )
 
 # if defined(ultrix) || defined(__ultrix__)
 	if (authenticate_user( p, curpass, NULL ) < 0)
+# elif defined(HAVE_PW_ENCRYPT)
+	if (strcmp( pw_encrypt( curpass, p->pw_passwd ), p->pw_passwd ))
 # elif defined(HAVE_CRYPT)
 	if (strcmp( crypt( curpass, p->pw_passwd ), p->pw_passwd ))
 # else
@@ -1461,7 +1479,7 @@ startClient( volatile int *pid )
 		if (setpenv( curuser, PENV_INIT | PENV_ARGV | PENV_NOEXEC,
 		             userEnviron, NULL ) != 0)
 		{
-			logError( "Can't set %s's process environment\n", curuser );
+			logError( "Cannot set %s's process environment\n", curuser );
 			goto cError;
 		}
 		userEnviron = newenv;
