@@ -605,14 +605,14 @@ void SystemTrayApplet::refreshExpandButton()
     if (orientation() == Qt::Vertical)
     {
         m_expandButton->setPixmap(m_showHidden ?
-            KIconLoader::global()->loadIcon("arrow-down", K3Icon::Panel, 16) :
-            KIconLoader::global()->loadIcon("arrow-up", K3Icon::Panel, 16));
+            KIconLoader::global()->loadIcon("arrow-down", KIconLoader::Panel, 16) :
+            KIconLoader::global()->loadIcon("arrow-up", KIconLoader::Panel, 16));
     }
     else
     {
         m_expandButton->setPixmap((m_showHidden ^ kapp->layoutDirection() == Qt::RightToLeft) ?
-            KIconLoader::global()->loadIcon("arrow-right", K3Icon::Panel, 16) :
-            KIconLoader::global()->loadIcon("arrow-left", K3Icon::Panel, 16));
+            KIconLoader::global()->loadIcon("arrow-right", KIconLoader::Panel, 16) :
+            KIconLoader::global()->loadIcon("arrow-left", KIconLoader::Panel, 16));
     }
 }
 
