@@ -51,6 +51,7 @@
 #include <kservice.h>
 #include <kservicegroup.h>
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kstandarddirs.h>
 #include <k3multipledrag.h>
 #include <k3urldrag.h>
@@ -140,7 +141,7 @@ void TreeItem::setup()
 
 static QPixmap appIcon(const QString &iconName)
 {
-    QPixmap normal = KIconLoader::global()->loadIcon(iconName, K3Icon::Small, 0, K3Icon::DefaultState, QStringList(), 0L, true);
+    QPixmap normal = KIconLoader::global()->loadIcon(iconName, KIconLoader::Small, 0, KIconLoader::DefaultState, QStringList(), 0L, true);
     // make sure they are not larger than 20x20
     if (normal.width() > 20 || normal.height() > 20)
     {
@@ -955,7 +956,7 @@ Q3DragObject *TreeView::dragObject()
        m_dragInfo = 0;
        m_dragItem = item;
        QString menuId = item->menuId();
-       m_dragPath = item->entryInfo()->service->desktopEntryPath();
+       m_dragPath = item->entryInfo()->service->entryPath();
        if (!m_dragPath.isEmpty())
           m_dragPath = KStandardDirs::locate("apps", m_dragPath);
        if (!m_dragPath.isEmpty())
