@@ -102,7 +102,7 @@ static Atom   gXA_SCREENSAVER_VERSION;
 //
 LockProcess::LockProcess(bool child, bool useBlankOnly)
     : QWidget(0L, Qt::X11BypassWindowManagerHint),
-      mOpenGLVisual(0),
+      mOpenGLVisual(false),
       child_saver(child),
       mParent(0),
       mUseBlankOnly(useBlankOnly),
@@ -363,7 +363,7 @@ void LockProcess::readSaver()
             kDebug(1204) << "Cannot find screesaver: " << mSaver;
             return;
         }
-        QString file = KStandardDirs::locate("services", offers.first()->desktopEntryPath());
+        QString file = KStandardDirs::locate("services", offers.first()->entryPath());
 
         bool opengl = KAuthorized::authorizeKAction("opengl_screensavers");
         bool manipulatescreen = KAuthorized::authorizeKAction("manipulatescreen_screensavers");
@@ -408,9 +408,11 @@ void LockProcess::readSaver()
 void LockProcess::createSaverWindow()
 {
     Visual* visual = CopyFromParent;
+    int depth = CopyFromParent;
     XSetWindowAttributes attrs;
-    int flags = 0;
+    int flags = CWOverrideRedirect;
 #ifdef HAVE_GLXCHOOSEVISUAL
+// this code is (partially) duplicated in kdebase/workspace/kcontrol/screensaver
     if( mOpenGLVisual )
     {
         static int attribs[][ 15 ] =
@@ -441,6 +443,7 @@ void LockProcess::createSaverWindow()
             if( XVisualInfo* info = glXChooseVisual( x11Info().display(), x11Info().screen(), attribs[ i ] ))
             {
                 visual = info->visual;
+                depth = info->depth;
                 static Colormap colormap = 0;
                 if( colormap != 0 )
                     XFreeColormap( x11Info().display(), colormap );
@@ -453,8 +456,10 @@ void LockProcess::createSaverWindow()
         }
     }
 #endif
+    attrs.override_redirect = 1;
+    hide();
     Window w = XCreateWindow( x11Info().display(), RootWindow( x11Info().display(), x11Info().screen()),
-        x(), y(), width(), height(), 0, x11Info().depth(), InputOutput, visual, flags, &attrs );
+        x(), y(), width(), height(), 0, depth, InputOutput, visual, flags, &attrs );
 
     create( w );
 
@@ -479,7 +484,6 @@ void LockProcess::createSaverWindow()
 
     setCursor( Qt::BlankCursor );
     setGeometry(0, 0, mRootWidth, mRootHeight);
-    hide();
 
     kDebug(1204) << "Saver window Id: " << winId();
 }
