@@ -73,7 +73,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <kapplication.h>
 #include <k3staticdeleter.h>
 #include <ktemporaryfile.h>
+#include <kconfiggroup.h>
 #include <kprocess.h>
+#include <kdebug.h>
 
 #include "server.h"
 #include "global.h"
@@ -140,7 +142,7 @@ void KSMServer::executeCommand( const QStringList& command )
 
 IceAuthDataEntry *authDataEntries = 0;
 
-static KTemporaryFile *remTempFile;
+static KTemporaryFile *remTempFile = 0;
 
 static IceListenObj *listenObjs = 0;
 int numTransports = 0;
@@ -392,7 +394,7 @@ Status SetAuthentication (int count, IceListenObj *listenObjs,
                           IceAuthDataEntry **authDataEntries)
 {
     KTemporaryFile addTempFile;
-    KTemporaryFile *remTempFile = new KTemporaryFile;
+    remTempFile = new KTemporaryFile;
 
     if (!addTempFile.open() || !remTempFile->open())
         return 0;
@@ -470,9 +472,12 @@ void FreeAuthenticationData(int count, IceAuthDataEntry *authDataEntries)
         return;
     }
 
-    KProcess p;
-    p << iceAuth << "source" << remTempFile->fileName();
-    p.execute();
+    if (remTempFile)
+    {
+        KProcess p;
+        p << iceAuth << "source" << remTempFile->fileName();
+        p.execute();
+    }
 
     delete remTempFile;
     remTempFile = 0;
@@ -643,7 +648,7 @@ KSMServer::KSMServer( const QString& windowManager, bool _only_local )
         f = ::fopen(fName.data(), "w+");
         if (!f)
         {
-            qWarning("KSMServer: can't open %s: %s", fName.data(), strerror(errno));
+            qWarning("KSMServer: cannot open %s: %s", fName.data(), strerror(errno));
             qWarning("KSMServer: Aborting.");
             exit(1);
         }
