@@ -62,6 +62,9 @@ FancyPlotter::FancyPlotter( QWidget* parent,
   mPlotter->installEventFilter( this );
 
   setPlotterWidget( mPlotter );
+
+  //Force a resize so that mPlotter's size gets set
+  FancyPlotter::resizeEvent( 0 );
 }
 
 FancyPlotter::~FancyPlotter()
@@ -260,9 +263,10 @@ void FancyPlotter::setTooltip()
 {
   QString tooltip;
 
-  tooltip = "<qt><table>";
 // FIXME:  reenable (and re-code) the following line when qt 4.3 or greater comes up 
-//  tooltip += "<table><tr><td><img src=\"" + mPlotter->getSnapshotImage(500,500).name() + "\"></td><td>";
+/*	tooltip = "<qt>";  
+	tooltip += "<table><tr><td><img src=\"" + mPlotter->getSnapshotImage(500,500).name() + "\"></td><td>";
+*/
   QString description;
   QString lastValue;
   for ( uint i = 0; i < mBeams; ++i ) {
@@ -285,13 +289,13 @@ void FancyPlotter::setTooltip()
     
 
     if(sensors().at( i)->isLocalhost()) {
-      tooltip += QString( "%1%2%3 (%4)" ).arg( i != 0 ? "<br>" : "<qt>")
+      tooltip += QString( "%1%2 %3 (%4)" ).arg( i != 0 ? "<br>" : "<qt>")
             .arg("<font color=\"" + mPlotter->beamColors()[ i ].name() + "\">"+indicatorSymbol+"</font>")
             .arg( description )
 	    .arg( lastValue );
 
     } else {
-      tooltip += QString( "%1%2%3:%4 (%5)" ).arg( i != 0 ? "<br>" : "<qt>" )
+      tooltip += QString( "%1%2 %3:%4 (%5)" ).arg( i != 0 ? "<br>" : "<qt>" )
                  .arg("<font color=\"" + mPlotter->beamColors()[ i ].name() + "\">"+indicatorSymbol+"</font>")
                  .arg( sensors().at( i )->hostName() )
                  .arg( description )
@@ -388,7 +392,7 @@ bool FancyPlotter::restoreSettings( QDomElement &element )
   }
 
   mPlotter->setShowVerticalLines( element.attribute( "vLines", "1" ).toUInt() );
-  QColor vcolor = restoreColor( element, "vColor",KSGRD::Style->firstForegroundColor() );
+  QColor vcolor = restoreColor( element, "vColor", KSGRD::Style->firstForegroundColor() );
   mPlotter->setVerticalLinesColor( vcolor );
   mPlotter->setVerticalLinesDistance( element.attribute( "vDistance", "30" ).toUInt() );
   mPlotter->setVerticalLinesScroll( element.attribute( "vScroll", "1" ).toUInt() );
