@@ -59,6 +59,7 @@ KSignalPlotter::KSignalPlotter( QWidget *parent)
 
   mShowVerticalLines = true;
   mVerticalLinesColor = QColor("black");
+  mVerticalLinesColor.setAlpha(127); //50% opacity
   mVerticalLinesDistance = 30;
   mVerticalLinesScroll = true;
   mVerticalLinesOffset = 0;
@@ -66,6 +67,7 @@ KSignalPlotter::KSignalPlotter( QWidget *parent)
 
   mShowHorizontalLines = true;
   mHorizontalLinesColor = QColor("black");
+  mHorizontalLinesColor.setAlpha(127); //50% opacity
   mHorizontalLinesCount = 5;
 
   mShowLabels = true;
@@ -97,7 +99,7 @@ void KSignalPlotter::addBeam( const QColor &color )
     (*it).append(0);
   }
   mBeamColors.append(color);
-  mBeamColorsDark.append(color.dark(150));
+  mBeamColorsDark.append(color.darker(150));
 }
 
 void KSignalPlotter::addSample( const QList<double>& sampleBuf )
@@ -152,8 +154,8 @@ void KSignalPlotter::reorderBeams( const QList<int>& newOrder )
       (*it) = newBeam;
     }
   }
-  QList< QColor> newBeamColors;
-  QList< QColor> newBeamColorsDark;
+  QList< QColor > newBeamColors;
+  QList< QColor > newBeamColorsDark;
   for(int i = 0; i < newOrder.count(); i++) {
     int newIndex = newOrder[i];
     newBeamColors.append(mBeamColors.at(newIndex));
@@ -841,14 +843,16 @@ void KSignalPlotter::drawBeams(QPainter *p, int top, int w, int h, int horizonta
         path.cubicTo( x1,y1-delta_y1,x2,y2-delta_y2,x3,y3-delta_y3 );
         
 	if(mFillBeams) {
+	  //The beams are filled with a gradient from mBeamColorsDark[j] to mBeamColors[j].
+	  //The fill's opacity is 90% of the opacity of the line
 	  QPainterPath path2(path);
           QLinearGradient myGradient(0,(h-1+top),0,(h-1+top)/5);
 	  Q_ASSERT(mBeamColorsDark.size() >= j);
 	  Q_ASSERT(mBeamColors.size() >= j);
 	  QColor c0(mBeamColorsDark[j]);
 	  QColor c1(mBeamColors[j]);
-	  c0.setAlpha(150);
-	  c1.setAlpha(150);
+	  c0.setAlphaF(c0.alphaF() * 0.9);
+	  c1.setAlphaF(c1.alphaF() * 0.9);
 	  myGradient.setColorAt(0, c0);
           myGradient.setColorAt(1, c1);
 
@@ -874,7 +878,15 @@ void KSignalPlotter::drawBeams(QPainter *p, int top, int w, int h, int horizonta
 	  y1-=delta_y1;
 	  y2-=delta_y2;
 	  y3-=delta_y3;
-	  offset = 1;  //see the comment further up for int offset;
+
+	  if (h > 100) {
+	    offset = 1;  //see the comment further up for int offset;
+	  }
+	  else {
+	    //When the display is very small, we have to draw the lines on top of each other
+	    //(otherwise every pixel of inaccuracy really starts to add up)
+	    offset = 0;
+	  }
 	}
       }
       if ( mUseAutoRange && mStackBeams) {
@@ -935,6 +947,12 @@ QString KSignalPlotter::lastValueAsString( int i) const
   if(mBeamData.isEmpty()) return QString();
   double value = mBeamData.first()[i] / mScaleDownBy; //retrieve the newest value for this beam then scale it correct
   QString number = KGlobal::locale()->formatNumber( value, (value >= 100)?0:2);
-  return QString( "%1 %2").arg(number, mUnit);
+
+  if (mUnit == "%" || mUnit == "") {
+    return QString( "%1%2" ).arg(number, mUnit);
+  }
+  else {
+    return QString( "%1 %2" ).arg(number, mUnit);
+  }
 }
 #include "SignalPlotter.moc"
