@@ -318,15 +318,9 @@ bool ProcessModel::isSimpleMode() const
 void ProcessModelPrivate::processChanged(KSysGuard::Process *process, bool onlyCpuOrMem)
 {
 	//FIXME
-	//There seem to be lots of bugs with qtreeview.  The idea here was to only update the actual rows
-	//that need changing.  However this seems to actually repaint completely the wrong cell.  I can only
-	//blame qt for this.
 	//
-	//So instead we will not call dataChanged here.  Instead after update, we will expand the first column.
-	//For some unknown reason (another bug?) this causes all the rows to be repainted, which is
-	//good enough for us
-
-	return;
+	//There is a bug with Qt in that updating a block of cells with dataChanged causes all of the cells to be repainted
+	//To work around this bug we emit dataChanged for cell, one at a time.
 
 	int row;
 	if(mSimple)
@@ -337,13 +331,15 @@ void ProcessModelPrivate::processChanged(KSysGuard::Process *process, bool onlyC
 	Q_ASSERT(row != -1);  //Something has gone very wrong
 	if(!onlyCpuOrMem) {
 		//Only the cpu usage changed, so only update that
-		QModelIndex index = q->createIndex(row, ProcessModel::HeadingCPUUsage, process);
-		QModelIndex index2 = q->createIndex(row, ProcessModel::HeadingSharedMemory, process);
-		emit q->dataChanged(index, index2);
+		for( int i = ProcessModel::HeadingCPUUsage; i<= ProcessModel::HeadingSharedMemory; ++i) {
+			QModelIndex index = q->createIndex(row, i, process);
+			emit q->dataChanged(index, index);
+		}
 	} else {
-		QModelIndex startIndex = q->createIndex(row, 0, process);
-		QModelIndex endIndex = q->createIndex(row, mHeadings.count()-1, process);
-		emit q->dataChanged(startIndex, endIndex);
+		for( int i = 0; i< mHeadings.count(); ++i) {
+			QModelIndex index = q->createIndex(row, i, process);
+			emit q->dataChanged(index, index);
+		}
 	}
 }
 
@@ -540,10 +536,10 @@ QString ProcessModelPrivate::getTooltipForUser(const KSysGuard::Process *ps) con
 			userTooltip = i18n("This user is not recognised for some reason");
 		else {
 			userTooltip = "<qt>";
-			if(!user.fullName().isEmpty()) userTooltip += i18n("<b>%1</b><br/>", user.fullName());
+            if(!user.property(KUser::FullName).isValid()) userTooltip += i18n("<b>%1</b><br/>", user.property(KUser::FullName).toString());
 			userTooltip += i18n("Login Name: %1 (uid: %2)<br/>", user.loginName(), ps->uid);
-			if(!user.roomNumber().isEmpty()) userTooltip += i18n("  Room Number: %1<br/>", user.roomNumber());
-			if(!user.workPhone().isEmpty()) userTooltip += i18n("  Work Phone: %1<br/>", user.workPhone());
+            if(!user.property(KUser::RoomNumber).isValid()) userTooltip += i18n("  Room Number: %1<br/>", user.property(KUser::RoomNumber).toString());
+            if(!user.property(KUser::WorkPhone).isValid()) userTooltip += i18n("  Work Phone: %1<br/>", user.property(KUser::WorkPhone).toString());
 		}
 	}
 	if( (ps->uid != ps->euid && ps->euid != -1) || 
@@ -938,8 +934,8 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 		} else if (index.column() == HeadingCPUUsage) {
 			KSysGuard::Process *process = reinterpret_cast< KSysGuard::Process * > (index.internalPointer());
 			if(process->status == KSysGuard::Process::Stopped || process->status == KSysGuard::Process::Zombie) {
-        			QPixmap pix = KIconLoader::global()->loadIcon("button_cancel", K3Icon::Small,
-			                K3Icon::SizeSmall, K3Icon::DefaultState, QStringList(),
+        			QPixmap pix = KIconLoader::global()->loadIcon("button_cancel", KIconLoader::Small,
+			                KIconLoader::SizeSmall, KIconLoader::DefaultState, QStringList(),
 				        0L, true);
 
 			}
