@@ -132,118 +132,156 @@ class ProgressBarItemDelegate : public QItemDelegate
 
 };
 
-KSysGuardProcessList::KSysGuardProcessList(QWidget* parent)
-	: QWidget(parent), mModel(this), mFilterModel(this), mUi(new Ui::ProcessWidget())
-{
-	mUpdateIntervalMSecs = 2000; //Set 2 seconds as the default update interval
-	mUi->setupUi(this);
-	mFilterModel.setSourceModel(&mModel);
-	mUi->treeView->setModel(&mFilterModel);
-#ifdef DO_MODELCHECK
-	new ModelTest(&mModel, this);
-#endif
-	mUi->treeView->setItemDelegate(new ProgressBarItemDelegate(mUi->treeView));
-
-	mColumnContextMenu = new QMenu(mUi->treeView->header());
-	connect(mColumnContextMenu, SIGNAL(triggered(QAction*)), this, SLOT(showOrHideColumn(QAction *)));
-	mUi->treeView->header()->setContextMenuPolicy(Qt::CustomContextMenu);
-	connect(mUi->treeView->header(), SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(showColumnContextMenu(const QPoint&)));
-
-	mProcessContextMenu = new QMenu(mUi->treeView);
-	mUi->treeView->setContextMenuPolicy(Qt::CustomContextMenu);
-	connect(mUi->treeView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(showProcessContextMenu(const QPoint&)));
+struct KSysGuardProcessListPrivate {
+    
+	KSysGuardProcessListPrivate(KSysGuardProcessList* q) : mModel(q), mFilterModel(q), mUi(new Ui::ProcessWidget()) {}
+    	/** The column context menu when you right click on a column.*/
+	QMenu *mColumnContextMenu;
 	
-	mUi->treeView->header()->setClickable(true);
-	mUi->treeView->header()->setSortIndicatorShown(true);
-	mUi->treeView->header()->setCascadingSectionResizes(true);
-	mUi->treeView->setSelectionMode( QAbstractItemView::ExtendedSelection );
-	connect(mUi->btnKillProcess, SIGNAL(clicked()), this, SLOT(killSelectedProcesses()));
-	connect(mUi->txtFilter, SIGNAL(textChanged(const QString &)), &mFilterModel, SLOT(setFilterRegExp(const QString &)));
-	connect(mUi->txtFilter, SIGNAL(textChanged(const QString &)), this, SLOT(expandInit()));
-	connect(mUi->cmbFilter, SIGNAL(currentIndexChanged(int)), this, SLOT(setStateInt(int)));
-	connect(mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
-	connect(mUi->treeView->selectionModel(), SIGNAL(currentRowChanged(const QModelIndex & , const QModelIndex & )), this, SLOT(currentRowChanged(const QModelIndex &)));
+	/** The context menu when you right click on a process */
+	QMenu *mProcessContextMenu;
+	
+	/** The process model.  This contains all the data on all the processes running on the system */
+	ProcessModel mModel;
+	
+	/** The process filter.  The mModel is connected to this, and this filter model connects to the view.  This lets us
+	 *  sort the view and filter (by using the combo box or the search line)
+	 */
+	ProcessFilter mFilterModel;
+	
+	/** The graphical user interface for this process list widget, auto-generated by Qt Designer */
+	Ui::ProcessWidget *mUi;
+
+	/** The time to wait, in milliseconds, between updating the process list */
+	int mUpdateIntervalMSecs;
+	
+	/** A timer to call updateList() every mUpdateIntervalMSecs */
+	QTimer *mUpdateTimer;
+
+	/** A timer to rapidly pulse a process being killed */
+	QTimer *mPulseTimer;
+};
+
+KSysGuardProcessList::KSysGuardProcessList(QWidget* parent)
+	: QWidget(parent), d(new KSysGuardProcessListPrivate(this))
+{
+	d->mUpdateIntervalMSecs = 2000; //Set 2 seconds as the default update interval
+	d->mUi->setupUi(this);
+	d->mFilterModel.setSourceModel(&d->mModel);
+	d->mUi->treeView->setModel(&d->mFilterModel);
+#ifdef DO_MODELCHECK
+	new ModelTest(&d->mModel, this);
+#endif
+	d->mUi->treeView->setItemDelegate(new ProgressBarItemDelegate(d->mUi->treeView));
+
+	d->mColumnContextMenu = new QMenu(d->mUi->treeView->header());
+	connect(d->mColumnContextMenu, SIGNAL(triggered(QAction*)), this, SLOT(showOrHideColumn(QAction *)));
+	d->mUi->treeView->header()->setContextMenuPolicy(Qt::CustomContextMenu);
+	connect(d->mUi->treeView->header(), SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(showColumnContextMenu(const QPoint&)));
+
+	d->mProcessContextMenu = new QMenu(d->mUi->treeView);
+	d->mUi->treeView->setContextMenuPolicy(Qt::CustomContextMenu);
+	connect(d->mUi->treeView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(showProcessContextMenu(const QPoint&)));
+
+	d->mUi->treeView->header()->setClickable(true);
+	d->mUi->treeView->header()->setSortIndicatorShown(true);
+	d->mUi->treeView->header()->setCascadingSectionResizes(true);
+	d->mUi->treeView->setSelectionMode( QAbstractItemView::ExtendedSelection );
+	connect(d->mUi->btnKillProcess, SIGNAL(clicked()), this, SLOT(killSelectedProcesses()));
+	connect(d->mUi->txtFilter, SIGNAL(textChanged(const QString &)), &d->mFilterModel, SLOT(setFilterRegExp(const QString &)));
+	connect(d->mUi->txtFilter, SIGNAL(textChanged(const QString &)), this, SLOT(expandInit()));
+	connect(d->mUi->cmbFilter, SIGNAL(currentIndexChanged(int)), this, SLOT(setStateInt(int)));
+	connect(d->mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
+	connect(d->mUi->treeView->selectionModel(), SIGNAL(currentRowChanged(const QModelIndex & , const QModelIndex & )), this, SLOT(currentRowChanged(const QModelIndex &)));
 	setMinimumSize(sizeHint());
 
         enum State {AllProcesses=0,AllProcessesInTreeForm, SystemProcesses, UserProcesses, OwnProcesses};
 
-	mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcesses, KIcon("view-process-all"));
-	mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcessesInTreeForm, KIcon("view-process-all-tree"));
-	mUi->cmbFilter->setItemIcon(ProcessFilter::SystemProcesses, KIcon("view-process-system"));
-	mUi->cmbFilter->setItemIcon(ProcessFilter::UserProcesses, KIcon("view-process-users"));
-	mUi->cmbFilter->setItemIcon(ProcessFilter::OwnProcesses, KIcon("view-process-own"));
+	d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcesses, KIcon("view-process-all"));
+	d->mUi->cmbFilter->setItemIcon(ProcessFilter::AllProcessesInTreeForm, KIcon("view-process-all-tree"));
+	d->mUi->cmbFilter->setItemIcon(ProcessFilter::SystemProcesses, KIcon("view-process-system"));
+	d->mUi->cmbFilter->setItemIcon(ProcessFilter::UserProcesses, KIcon("view-process-users"));
+	d->mUi->cmbFilter->setItemIcon(ProcessFilter::OwnProcesses, KIcon("view-process-own"));
 
 	/*  Hide the vm size column by default since it's not very useful */
-	mUi->treeView->header()->hideSection(ProcessModel::HeadingVmSize);
-	mUi->treeView->header()->hideSection(ProcessModel::HeadingNiceness);
-	mUi->treeView->header()->hideSection(ProcessModel::HeadingTty);
-	mUi->treeView->header()->hideSection(ProcessModel::HeadingCommand);
-	mFilterModel.setFilterKeyColumn(0);
+	d->mUi->treeView->header()->hideSection(ProcessModel::HeadingVmSize);
+	d->mUi->treeView->header()->hideSection(ProcessModel::HeadingNiceness);
+	d->mUi->treeView->header()->hideSection(ProcessModel::HeadingTty);
+	d->mUi->treeView->header()->hideSection(ProcessModel::HeadingCommand);
+	d->mFilterModel.setFilterKeyColumn(0);
 
 	//Process names can have mixed case. Make the filter case insensitive.
-	mFilterModel.setFilterCaseSensitivity(Qt::CaseInsensitive);
+	d->mFilterModel.setFilterCaseSensitivity(Qt::CaseInsensitive);
 
 	//Logical column 0 will always be the tree bit with the process name.  We expand this automatically in code,
 	//so don't let the user change it
-	mUi->treeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
-	mUi->treeView->header()->setStretchLastSection(true);
+	d->mUi->treeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+	d->mUi->treeView->header()->setStretchLastSection(true);
 
 	//Sort by username by default
-	mUi->treeView->sortByColumn(ProcessModel::HeadingUser, Qt::AscendingOrder);
-	mFilterModel.sort(ProcessModel::HeadingUser, Qt::AscendingOrder);
-	mFilterModel.setDynamicSortFilter(true);
+	d->mUi->treeView->sortByColumn(ProcessModel::HeadingUser, Qt::AscendingOrder);
+	d->mFilterModel.sort(ProcessModel::HeadingUser, Qt::AscendingOrder);
+	
+	// Dynamic sort filter seems to require repainting the whole screen, slowing everything down drastically.
+	// When this bug is fixed we can re-enable this.
+	//d->mFilterModel.setDynamicSortFilter(true);
 
-	mUpdateTimer = new QTimer(this);
-	mUpdateTimer->setSingleShot(true);
-	connect(mUpdateTimer, SIGNAL(timeout()), this, SLOT(updateList()));
-	mUpdateTimer->start(mUpdateIntervalMSecs);
+	d->mUpdateTimer = new QTimer(this);
+	d->mUpdateTimer->setSingleShot(true);
+	connect(d->mUpdateTimer, SIGNAL(timeout()), this, SLOT(updateList()));
+	d->mUpdateTimer->start(d->mUpdateIntervalMSecs);
 
 	//If the view resorts continually, then it can be hard to keep track of processes.  By doing it only every few seconds it reduces the 'jumping around'
 	QTimer *mTimer = new QTimer(this);
-	connect(mTimer, SIGNAL(timeout()), &mFilterModel, SLOT(invalidate()));
-	mTimer->start(6000); 
+	connect(mTimer, SIGNAL(timeout()), &d->mFilterModel, SLOT(invalidate()));
+	mTimer->start(10000); 
 
 	expandInit(); //This will expand the init process
 }
 
+KSysGuardProcessList::~KSysGuardProcessList()
+{
+    delete d;
+}
+
 QTreeView *KSysGuardProcessList::treeView() const {
-	return mUi->treeView;
+	return d->mUi->treeView;
 }
 
 QLineEdit *KSysGuardProcessList::filterLineEdit() const {
-	return mUi->txtFilter;
+	return d->mUi->txtFilter;
 }
 
 ProcessFilter::State KSysGuardProcessList::state() const 
 {
-	return mFilterModel.filter();
+	return d->mFilterModel.filter();
 }
 void KSysGuardProcessList::setStateInt(int state) {
 	setState((ProcessFilter::State) state);
 }
 void KSysGuardProcessList::setState(ProcessFilter::State state)
 {  //index is the item the user selected in the combo box
-	mFilterModel.setFilter(state);
-	mModel.setSimpleMode( (state != ProcessFilter::AllProcessesInTreeForm) );
-	mUi->cmbFilter->setCurrentIndex( (int)state);
+	d->mFilterModel.setFilter(state);
+	d->mModel.setSimpleMode( (state != ProcessFilter::AllProcessesInTreeForm) );
+	d->mUi->cmbFilter->setCurrentIndex( (int)state);
 }
 void KSysGuardProcessList::currentRowChanged(const QModelIndex &current)
 {
-	mUi->btnKillProcess->setEnabled(current.isValid());
+	d->mUi->btnKillProcess->setEnabled(current.isValid());
 }
 void KSysGuardProcessList::showProcessContextMenu(const QPoint &point){
-	mProcessContextMenu->clear();
+	d->mProcessContextMenu->clear();
 
-	QAction *renice = new QAction(mProcessContextMenu);
+	QAction *renice = new QAction(d->mProcessContextMenu);
 	renice->setText(i18n("Renice Process..."));
-	mProcessContextMenu->addAction(renice);
+	d->mProcessContextMenu->addAction(renice);
 
-	QAction *kill = new QAction(mProcessContextMenu);
+	QAction *kill = new QAction(d->mProcessContextMenu);
 	kill->setText(i18n("Kill Process"));
 	kill->setIcon(KIcon("stop"));
-	mProcessContextMenu->addAction(kill);
+	d->mProcessContextMenu->addAction(kill);
 
-	QAction *result = mProcessContextMenu->exec(mUi->treeView->mapToGlobal(point));	
+	QAction *result = d->mProcessContextMenu->exec(d->mUi->treeView->mapToGlobal(point));	
 	if(result == renice) {
 		reniceSelectedProcesses();
 	} else if(result == kill) {
@@ -252,34 +290,34 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point){
 }
 
 void KSysGuardProcessList::showColumnContextMenu(const QPoint &point){
-	mColumnContextMenu->clear();
+	d->mColumnContextMenu->clear();
 	
 	{
-		int index = mUi->treeView->header()->logicalIndexAt(point);
+		int index = d->mUi->treeView->header()->logicalIndexAt(point);
 		if(index >= 0) {
 			//selected a column.  Give the option to hide it
-			QAction *action = new QAction(mColumnContextMenu);
+			QAction *action = new QAction(d->mColumnContextMenu);
 			action->setData(-index-1); //We set data to be negative (and minus 1) to hide a column, and positive to show a column
-			action->setText(i18n("Hide column '%1'", mFilterModel.headerData(index, Qt::Horizontal, Qt::DisplayRole).toString()));
-			mColumnContextMenu->addAction(action);
-			if(mUi->treeView->header()->sectionsHidden()) {
-				mColumnContextMenu->addSeparator();
+			action->setText(i18n("Hide column '%1'", d->mFilterModel.headerData(index, Qt::Horizontal, Qt::DisplayRole).toString()));
+			d->mColumnContextMenu->addAction(action);
+			if(d->mUi->treeView->header()->sectionsHidden()) {
+				d->mColumnContextMenu->addSeparator();
 			}
 		}
 	}
 
-	if(mUi->treeView->header()->sectionsHidden()) {
-		int num_headings = mFilterModel.columnCount();
+	if(d->mUi->treeView->header()->sectionsHidden()) {
+		int num_headings = d->mFilterModel.columnCount();
 		for(int i = 0; i < num_headings; ++i) {
-			if(mUi->treeView->header()->isSectionHidden(i)) {
-				QAction *action = new QAction(mColumnContextMenu);
-				action->setText(i18n("Show column '%1'", mFilterModel.headerData(i, Qt::Horizontal, Qt::DisplayRole).toString()));
+			if(d->mUi->treeView->header()->isSectionHidden(i)) {
+				QAction *action = new QAction(d->mColumnContextMenu);
+				action->setText(i18n("Show column '%1'", d->mFilterModel.headerData(i, Qt::Horizontal, Qt::DisplayRole).toString()));
 				action->setData(i); //We set data to be negative (and minus 1) to hide a column, and positive to show a column
-				mColumnContextMenu->addAction(action);
+				d->mColumnContextMenu->addAction(action);
 			}
 		}
 	}
-	mColumnContextMenu->exec(mUi->treeView->header()->mapToGlobal(point));	
+	d->mColumnContextMenu->exec(d->mUi->treeView->header()->mapToGlobal(point));	
 }
 
 void KSysGuardProcessList::showOrHideColumn(QAction *action)
@@ -287,11 +325,11 @@ void KSysGuardProcessList::showOrHideColumn(QAction *action)
 	int index = action->data().toInt();
 	//We set data to be negative to hide a column, and positive to show a column
 	if(index < 0)
-		mUi->treeView->hideColumn(-1-index);
+		d->mUi->treeView->hideColumn(-1-index);
 	else {
-		mUi->treeView->showColumn(index);
-		mUi->treeView->resizeColumnToContents(index);
-		mUi->treeView->resizeColumnToContents(mFilterModel.columnCount());
+		d->mUi->treeView->showColumn(index);
+		d->mUi->treeView->resizeColumnToContents(index);
+		d->mUi->treeView->resizeColumnToContents(d->mFilterModel.columnCount());
 	}
 		
 }
@@ -300,64 +338,63 @@ void KSysGuardProcessList::expandAllChildren(const QModelIndex &parent)
 {
 	//This is called when the user expands a node.  This then expands all of its 
 	//children.  This will trigger this function again recursively.
-	QModelIndex sourceParent = mFilterModel.mapToSource(parent);
-	for(int i = 0; i < mModel.rowCount(sourceParent); i++) 
-		mUi->treeView->expand(mFilterModel.mapFromSource(mModel.index(i,0, sourceParent)));
+	QModelIndex sourceParent = d->mFilterModel.mapToSource(parent);
+	for(int i = 0; i < d->mModel.rowCount(sourceParent); i++) 
+		d->mUi->treeView->expand(d->mFilterModel.mapFromSource(d->mModel.index(i,0, sourceParent)));
 }
 
 void KSysGuardProcessList::expandInit()
 {
 	//When we expand the items, make sure we don't call our expand all children function
-	disconnect(mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
-	mUi->treeView->expand(mFilterModel.mapFromSource(mModel.index(0,0, QModelIndex())));
-	connect(mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
+	disconnect(d->mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
+	d->mUi->treeView->expand(d->mFilterModel.mapFromSource(d->mModel.index(0,0, QModelIndex())));
+	connect(d->mUi->treeView, SIGNAL(expanded(const QModelIndex &)), this, SLOT(expandAllChildren(const QModelIndex &)));
 }
 
 void KSysGuardProcessList::hideEvent ( QHideEvent * event )  //virtual protected from QWidget
 {
 	//Stop updating the process list if we are hidden
-	mUpdateTimer->stop();
+	d->mUpdateTimer->stop();
 	QWidget::hideEvent(event);
 }
 
 void KSysGuardProcessList::showEvent ( QShowEvent * event )  //virtual protected from QWidget
 {
 	//Start updating the process list again if we are shown again
-	if(!mUpdateTimer->isActive()) 
-		mUpdateTimer->start(mUpdateIntervalMSecs);
+	if(!d->mUpdateTimer->isActive()) 
+		d->mUpdateTimer->start(d->mUpdateIntervalMSecs);
 	QWidget::showEvent(event);
 }
 
 void KSysGuardProcessList::updateList()
 {
 	if(isVisible()) {
-		mModel.update(mUpdateIntervalMSecs);
-		expandInit();
-		mUpdateTimer->start(mUpdateIntervalMSecs);
+		d->mModel.update(d->mUpdateIntervalMSecs);
+		d->mUpdateTimer->start(d->mUpdateIntervalMSecs);
 	}
 }
 
 int KSysGuardProcessList::updateIntervalMSecs() const 
 {
-	return mUpdateIntervalMSecs;
+	return d->mUpdateIntervalMSecs;
 }	
 
 void KSysGuardProcessList::setUpdateIntervalMSecs(int intervalMSecs) 
 {
-	mUpdateIntervalMSecs = intervalMSecs;
-	mUpdateTimer->setInterval(mUpdateIntervalMSecs);
+	d->mUpdateIntervalMSecs = intervalMSecs;
+	d->mUpdateTimer->setInterval(d->mUpdateIntervalMSecs);
 }
 
 void KSysGuardProcessList::reniceProcesses(const QList<long long> &pids, int niceValue)
 {
 	QList< long long> unreniced_pids;
         for (int i = 0; i < pids.size(); ++i) {
-		bool success = mModel.processController()->setNiceness(pids.at(i), niceValue);
+		bool success = d->mModel.processController()->setNiceness(pids.at(i), niceValue);
 		if(!success)
 			unreniced_pids << pids.at(i);
 	}
 	if(unreniced_pids.isEmpty()) return; //All processes were reniced successfully
-	if(!mModel.isLocalhost()) return; //We can't use kdesu to renice non-localhost processes
+	if(!d->mModel.isLocalhost()) return; //We can't use kdesu to renice non-localhost processes
 	
 	QStringList arguments;
 	arguments << "--" << "renice" << QString::number(niceValue);
@@ -371,25 +408,38 @@ void KSysGuardProcessList::reniceProcesses(const QList<long long> &pids, int nic
 	reniceProcess->start("kdesu", arguments);
 }
 
+QList<KSysGuard::Process *> KSysGuardProcessList::selectedProcesses() const
+{
+	QList<KSysGuard::Process *> processes;
+	QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
+	for(int i = 0; i < selectedIndexes.size(); ++i) {
+		KSysGuard::Process *process = reinterpret_cast<KSysGuard::Process *> (d->mFilterModel.mapToSource(selectedIndexes.at(i)).internalPointer());
+		processes << process;
+	}
+	return processes;
+
+}
+
 void KSysGuardProcessList::reniceSelectedProcesses()
 {
-	QModelIndexList selectedIndexes = mUi->treeView->selectionModel()->selectedRows();
+	QList<KSysGuard::Process *> processes = selectedProcesses();
 	QStringList selectedAsStrings;
 	QList< long long> selectedPids;
-	int firstPriority = 0;
-	for (int i = 0; i < selectedIndexes.size(); ++i) {
-		KSysGuard::Process *process = reinterpret_cast<KSysGuard::Process *> (mFilterModel.mapToSource(selectedIndexes.at(i)).internalPointer());
-		if(i==0) firstPriority = process->niceLevel;
-		selectedPids << process->pid;
-		selectedAsStrings << mModel.getStringForProcess(process);
-	}
 	
-	if (selectedAsStrings.isEmpty())
+	if (processes.isEmpty())
 	{
 		KMessageBox::sorry(this, i18n("You need to select a process first."));
 		return;
 	}
-	ReniceDlg reniceDlg(mUi->treeView, firstPriority, selectedAsStrings);
+
+	int firstPriority = 0;
+	foreach(KSysGuard::Process *process, processes) {
+		selectedPids << process->pid;
+		selectedAsStrings << d->mModel.getStringForProcess(process);
+	}
+	firstPriority = processes.first()->niceLevel;
+
+	ReniceDlg reniceDlg(d->mUi->treeView, firstPriority, selectedAsStrings);
 	if(reniceDlg.exec() == QDialog::Rejected) return;
 	int newPriority = reniceDlg.newPriority;
 	Q_ASSERT(newPriority <= 19 && newPriority >= -20); 
@@ -403,12 +453,12 @@ void KSysGuardProcessList::killProcesses(const QList< long long> &pids, int sig)
 {
 	QList< long long> unkilled_pids;
         for (int i = 0; i < pids.size(); ++i) {
-		bool success = mModel.processController()->sendSignal(pids.at(i), sig);
+		bool success = d->mModel.processController()->sendSignal(pids.at(i), sig);
 		if(!success)
 			unkilled_pids << pids.at(i);
 	}
 	if(unkilled_pids.isEmpty()) return;
-	if(!mModel.isLocalhost()) return; //We can't use kdesu to kill non-localhost processes
+	if(!d->mModel.isLocalhost()) return; //We can't use kdesu to kill non-localhost processes
 
 	//We must use kdesu to kill the process
 	QStringList arguments;
@@ -427,15 +477,14 @@ void KSysGuardProcessList::killProcesses(const QList< long long> &pids, int sig)
 }
 void KSysGuardProcessList::killSelectedProcesses()
 {
-	QModelIndexList selectedIndexes = mUi->treeView->selectionModel()->selectedRows();
+	QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
 	QStringList selectedAsStrings;
 	QList< long long> selectedPids;
-	QList<KSysGuard::Process *> selectedProcesses;
-	for (int i = 0; i < selectedIndexes.size(); ++i) {
-		KSysGuard::Process *process = reinterpret_cast<KSysGuard::Process *> (mFilterModel.mapToSource(selectedIndexes.at(i)).internalPointer());
-		selectedProcesses << process;
+
+	QList<KSysGuard::Process *> processes = selectedProcesses();
+	foreach(KSysGuard::Process *process, processes) {
 		selectedPids << process->pid;
-		selectedAsStrings << mModel.getStringForProcess(process);
+		selectedAsStrings << d->mModel.getStringForProcess(process);
 	}
 	
 	if (selectedAsStrings.isEmpty())
@@ -459,7 +508,7 @@ void KSysGuardProcessList::killSelectedProcesses()
 			return;
 		}
 	}
-	foreach(KSysGuard::Process *process, selectedProcesses) {
+	foreach(KSysGuard::Process *process, processes) {
 		process->timeKillWasSent.start();
 	}
 
@@ -480,10 +529,10 @@ void KSysGuardProcessList::killFailed()
 }
 
 bool KSysGuardProcessList::showTotals() const {
-	return mModel.showTotals();
+	return d->mModel.showTotals();
 }
 
 void KSysGuardProcessList::setShowTotals(bool showTotals)  //slot
 {
-	mModel.setShowTotals(showTotals);
+	d->mModel.setShowTotals(showTotals);
 }
