@@ -27,8 +27,8 @@
 #include <QResizeEvent>
 #include <QMouseEvent>
 #include <QPainter>
-#include <kpixmapeffect.h>
-#include <kimageeffect.h>
+#include <QUrl>
+#include <QTextStream>
 #include <kicontheme.h>
 #include <kiconeffect.h>
 //#include <kdrawutil.h>
@@ -39,6 +39,8 @@
 
 #include <X11/Xlib.h>
 #include <QX11Info>
+#include <KUrl>
+#include <KConfigGroup>
 #include <KDebug>
 
 namespace B2 {
@@ -414,6 +416,7 @@ void B2Client::init()
 	QLabel *previewLabel = new QLabel(
 		i18n("<b><center>B II preview</center></b>"),
 		widget());
+        previewLabel->setAutoFillBackground(true);
         g->addWidget(previewLabel, 1, 1);
     } else {
 	g->addItem(new QSpacerItem(0, 0), 1, 1);
@@ -1105,11 +1108,11 @@ static void redraw_pixmaps()
     for (int i = 0; i < P_NUM_BUTTON_TYPES; i++) {
 	int offset = i * NumStates;
 	hilighted = ie.apply(*pixmap[offset + Norm],
-		K3Icon::Small, K3Icon::ActiveState);
+		KIconLoader::Small, KIconLoader::ActiveState);
 	*pixmap[offset + Hover] = hilighted;
 
 	hilighted = ie.apply(*pixmap[offset + INorm],
-		K3Icon::Small, K3Icon::ActiveState);
+		KIconLoader::Small, KIconLoader::ActiveState);
 	*pixmap[offset + IHover] = hilighted;
     }
 
