@@ -24,9 +24,8 @@
 #include <QPainter>
 #include <QImage>
 
-#include <kconfig.h>
+#include <kconfiggroup.h>
 #include <QPixmap>
-#include <kpixmapeffect.h>
 
 #include "misc.h"
 #include "plastik.h"
@@ -34,6 +33,7 @@
 #include "plastikclient.h"
 #include "plastikbutton.h"
 #include <QApplication>
+#include <kconfig.h>
 
 namespace KWinPlastik
 {
@@ -168,7 +168,7 @@ void PlastikHandler::readConfig()
 
     QFontMetrics fm(m_titleFont);  // active font = inactive font
     int titleHeightMin = config.readEntry("MinTitleHeight", 16);
-    // The title should strech with bigger font sizes!
+    // The title should stretch with bigger font sizes!
     m_titleHeight = qMax(titleHeightMin, fm.height() + 4); // 4 px for the shadow etc.
     // have an even title/button size so the button icons are fully centered...
     if ( m_titleHeight%2 == 0)
@@ -176,7 +176,7 @@ void PlastikHandler::readConfig()
 
     fm = QFontMetrics(m_titleFontTool);  // active font = inactive font
     int titleHeightToolMin = config.readEntry("MinTitleHeightTool", 13);
-    // The title should strech with bigger font sizes!
+    // The title should stretch with bigger font sizes!
     m_titleHeightTool = qMax(titleHeightToolMin, fm.height() ); // don't care about the shadow etc.
     // have an even title/button size so the button icons are fully centered...
     if ( m_titleHeightTool%2 == 0)
@@ -239,18 +239,14 @@ const QPixmap &PlastikHandler::pixmap(Pixmaps type, bool active, bool toolWindow
             const int gradientHeight = 2 + titleBarTileHeight-1;
             QPixmap gradient(1, gradientHeight);
             QPainter painter(&gradient);
-            QPixmap tempPixmap( 1, 4 );
-            KPixmapEffect::gradient(tempPixmap,
-                                    getColor(TitleGradient1, active),
-                                    getColor(TitleGradient2, active),
-                                    KPixmapEffect::VerticalGradient);
-            painter.drawPixmap(0,0, tempPixmap);
-            tempPixmap = QPixmap(1, gradientHeight-4);
-            KPixmapEffect::gradient(tempPixmap,
-                                    getColor(TitleGradient2, active),
-                                    getColor(TitleGradient3, active),
-                                    KPixmapEffect::VerticalGradient);
-            painter.drawPixmap(0,4, tempPixmap);
+            painter.setPen(Qt::NoPen);
+            QLinearGradient grad(0, 0, 0, gradientHeight);
+            grad.setColorAt(0.0,                                  getColor(TitleGradient1, active));
+            grad.setColorAt(4.0 / (double)gradientHeight,         getColor(TitleGradient2, active));
+            grad.setColorAt(1.0 - (4.0 / (double)gradientHeight), getColor(TitleGradient2, active));
+            grad.setColorAt(1.0,                                  getColor(TitleGradient3, active));
+            painter.setBrush(grad);
+            painter.drawRect(0, 0, 1, gradientHeight);
             painter.end();
 
             // actual titlebar tiles
