@@ -39,6 +39,11 @@ BoxSwitchEffect::BoxSwitchEffect()
 #ifdef HAVE_XRENDER
     alphaFormat = XRenderFindStandardFormat( display(), PictStandardARGB32 );
 #endif
+    color_frame = KColorScheme( QPalette::Active, KColorScheme::Window ).background();
+    color_frame.setAlphaF( 0.9 );
+    color_highlight = KColorScheme( QPalette::Active, KColorScheme::Selection ).background();
+    color_highlight.setAlphaF( 0.9 );
+    color_text = KColorScheme( QPalette::Active, KColorScheme::Window ).foreground();
     }
 
 BoxSwitchEffect::~BoxSwitchEffect()
@@ -91,7 +96,7 @@ void BoxSwitchEffect::paintScreen( int mask, QRegion region, ScreenPaintData& da
                 paintWindowThumbnail( w );
                 paintWindowIcon( w );
                 }
-            paintText( text_area, selected_window->caption());
+            paintText( selected_window->caption() );
             }
         else
             {
@@ -108,7 +113,7 @@ void BoxSwitchEffect::paintScreen( int mask, QRegion region, ScreenPaintData& da
 
                     paintDesktopThumbnail( painting_desktop );
                     }
-                paintText( text_area, effects->desktopName( selected_desktop ));
+                paintText( effects->desktopName( selected_desktop ));
                 painting_desktop = 0;
                 }
             }
@@ -377,7 +382,11 @@ void BoxSwitchEffect::calculateFrameSize()
         item_max_size.setHeight( 200 );
         }
     // How much height to reserve for a one-line text label
-    text_area.setHeight( int( kapp->fontMetrics().height() * 1.2 ));
+    text_font.setBold( true );
+    text_font.setPointSize( 12 );
+    text_area.setHeight( QFontMetrics( text_font ).height() * 1.2 );
+    // Separator space between items and text
+    const int separator_height = 6;
     // Shrink the size until all windows/desktops can fit onscreen
     frame_area.setWidth( frame_margin * 2 + itemcount * item_max_size.width());
     while( frame_area.width() > displayWidth())
@@ -385,11 +394,13 @@ void BoxSwitchEffect::calculateFrameSize()
         item_max_size /= 2;
         frame_area.setWidth( frame_margin * 2 + itemcount * item_max_size.width());
         }
-    frame_area.setHeight( frame_margin * 2 + item_max_size.height() + text_area.height());
+    frame_area.setHeight( frame_margin * 2 + item_max_size.height() +
+            separator_height + text_area.height());
     text_area.setWidth( frame_area.width() - frame_margin * 2 );
 
     frame_area.moveTo(( displayWidth() - frame_area.width()) / 2, ( displayHeight() - frame_area.height()) / 2 );
-    text_area.moveTo( frame_area.x() + frame_margin, frame_area.y() + frame_margin + item_max_size.height());
+    text_area.moveTo( frame_area.x() + frame_margin,
+                      frame_area.y() + frame_margin + item_max_size.height() + separator_height);
     }
 
 void BoxSwitchEffect::calculateItemSizes()
@@ -428,13 +439,11 @@ void BoxSwitchEffect::calculateItemSizes()
 
 void BoxSwitchEffect::paintFrame()
     {
-    QColor color = KColorScheme( KColorScheme::Window ).background();
-    color.setAlphaF( 0.9 );
 #ifdef HAVE_OPENGL
     if( effects->compositingType() == OpenGLCompositing )
         {
         glPushAttrib( GL_CURRENT_BIT );
-        glColor4f( color.redF(), color.greenF(), color.blueF(), color.alphaF());
+        glColor4f( color_frame.redF(), color_frame.greenF(), color_frame.blueF(), color_frame.alphaF());
         renderRoundBoxWithEdge( frame_area );
         glPopAttrib();
         }
@@ -447,13 +456,13 @@ void BoxSwitchEffect::paintFrame()
         Picture pic = XRenderCreatePicture( display(), pixmap, alphaFormat, 0, NULL );
         XFreePixmap( display(), pixmap );
         XRenderColor col;
-        col.alpha = int( color.alphaF() * 0xffff );
-        col.red = int( color.redF() * color.alphaF() * 0xffff );
-        col.green = int( color.greenF() * color.alphaF() * 0xffff );
-        col.blue = int( color.blueF() * color.alphaF() * 0xffff );
+        col.alpha = int( color_frame.alphaF() * 0xffff );
+        col.red = int( color_frame.redF() * color_frame.alphaF() * 0xffff );
+        col.green = int( color_frame.greenF() * color_frame.alphaF() * 0xffff );
+        col.blue = int( color_frame.blueF() * color_frame.alphaF() * 0xffff );
         XRenderFillRectangle( display(), PictOpSrc, pic, &col, 0, 0,
             frame_area.width(), frame_area.height());
-        XRenderComposite( display(), color.alphaF() != 1.0 ? PictOpOver : PictOpSrc,
+        XRenderComposite( display(), color_frame.alphaF() != 1.0 ? PictOpOver : PictOpSrc,
             pic, None, effects->xrenderBufferPicture(),
             0, 0, 0, 0, frame_area.x(), frame_area.y(), frame_area.width(), frame_area.height());
         XRenderFreePicture( display(), pic );
@@ -463,13 +472,11 @@ void BoxSwitchEffect::paintFrame()
 
 void BoxSwitchEffect::paintHighlight( QRect area )
     {
-    QColor color = KColorScheme( KColorScheme::Selection ).background();
-    color.setAlphaF( 0.9 );
 #ifdef HAVE_OPENGL
     if( effects->compositingType() == OpenGLCompositing )
         {
         glPushAttrib( GL_CURRENT_BIT );
-        glColor4f( color.redF(), color.greenF(), color.blueF(), color.alphaF());
+        glColor4f( color_highlight.redF(), color_highlight.greenF(), color_highlight.blueF(), color_highlight.alphaF());
         renderRoundBox( area, 6 );
         glPopAttrib();
         }
@@ -482,13 +489,13 @@ void BoxSwitchEffect::paintHighlight( QRect area )
         Picture pic = XRenderCreatePicture( display(), pixmap, alphaFormat, 0, NULL );
         XFreePixmap( display(), pixmap );
         XRenderColor col;
-        col.alpha = int( color.alphaF() * 0xffff );
-        col.red = int( color.redF() * color.alphaF() * 0xffff );
-        col.green = int( color.greenF() * color.alphaF() * 0xffff );
-        col.blue = int( color.blueF() * color.alphaF() * 0xffff );
+        col.alpha = int( color_highlight.alphaF() * 0xffff );
+        col.red = int( color_highlight.redF() * color_highlight.alphaF() * 0xffff );
+        col.green = int( color_highlight.greenF() * color_highlight.alphaF() * 0xffff );
+        col.blue = int( color_highlight.blueF() * color_highlight.alphaF() * 0xffff );
         XRenderFillRectangle( display(), PictOpSrc, pic, &col, 0, 0,
             area.width(), area.height());
-        XRenderComposite( display(), color.alphaF() != 1.0 ? PictOpOver : PictOpSrc,
+        XRenderComposite( display(), color_highlight.alphaF() != 1.0 ? PictOpOver : PictOpSrc,
             pic, None, effects->xrenderBufferPicture(),
             0, 0, 0, 0, area.x(), area.y(), area.width(), area.height());
         XRenderFreePicture( display(), pic );
@@ -524,8 +531,8 @@ void BoxSwitchEffect::paintDesktopThumbnail( int iDesktop )
     QSize size = QSize( displayWidth(), displayHeight());
 
     size.scale( r.size(), Qt::KeepAspectRatio );
-    data.xScale = size.width() / float( displayWidth());
-    data.yScale = size.height() / float( displayHeight());
+    data.xScale = size.width() / double( displayWidth());
+    data.yScale = size.height() / double( displayHeight());
     int width = int( displayWidth() * data.xScale );
     int height = int( displayHeight() * data.yScale );
     int x = r.x() + ( r.width() - width ) / 2;
@@ -615,59 +622,10 @@ void BoxSwitchEffect::paintWindowIcon( EffectWindow* w )
 #endif
     }
 
-void BoxSwitchEffect::paintText( QRect area, QString text )
-    {
-    QPainter p;
-
-    textPixmap = QPixmap( area.width(), area.height());
-    textPixmap.fill( Qt::transparent );
-
-    p.begin( &textPixmap );
-    p.setRenderHint( QPainter::TextAntialiasing );
-    p.setPen( KColorScheme( KColorScheme::Window ).foreground());
-    p.drawText( 0, 0, textPixmap.width(), textPixmap.height(),
-        Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextSingleLine,
-        p.fontMetrics().elidedText( text, Qt::ElideMiddle, textPixmap.width()));
-    p.end();
-
-#ifdef HAVE_OPENGL
-    if( effects->compositingType() == OpenGLCompositing )
-        {
-        textTexture.load( textPixmap, GL_TEXTURE_RECTANGLE_ARB );
-        glPushAttrib( GL_CURRENT_BIT | GL_ENABLE_BIT );
-        glEnable( GL_BLEND );
-        glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );
-        textTexture.bind();
-        const float verts[ 4 * 2 ] = 
-            {
-            area.x(), area.y(),
-            area.x(), area.y() + area.height(),
-            area.x() + area.width(), area.y() + area.height(),
-            area.x() + area.width(), area.y()
-            };
-        const float texcoords[ 4 * 2 ] =
-            {
-            0, textPixmap.height(),
-            0, 0,
-            textPixmap.width(), 0,
-            textPixmap.width(), textPixmap.height()
-            };
-        renderGLGeometry( 4, verts, texcoords );
-        textTexture.unbind();
-        glPopAttrib();
-        }
-#endif
-#ifdef HAVE_XRENDER
-    if( effects->compositingType() == XRenderCompositing )
-        {
-        if( textPicture != None )
-            XRenderFreePicture( display(), textPicture );
-        textPicture = XRenderCreatePicture( display(), textPixmap.handle(), alphaFormat, 0, NULL );
-        XRenderComposite( display(), textPixmap.depth() == 32 ? PictOpOver : PictOpSrc,
-        textPicture, None, effects->xrenderBufferPicture(),
-        0, 0, 0, 0, area.x(), area.y(), area.width(), area.height());
-        }
-#endif
-    }
+void BoxSwitchEffect::paintText( const QString& text )
+{
+    int maxwidth = text_area.width();
+    effects->paintText( text, text_area.center(), maxwidth, color_text, text_font );
+}
 
 } // namespace
