@@ -28,7 +28,7 @@ class ScaleInEffect
         virtual void windowAdded( EffectWindow* c );
         virtual void windowClosed( EffectWindow* c );
     private:
-        QHash< const EffectWindow*, float > windows;
+        QHash< const EffectWindow*, double > windows;
     };
 
 } // namespace
