@@ -35,8 +35,10 @@ class ShadowEffect
         QRect shadowRectangle(const QRect& windowRectangle) const;
 
         int shadowXOffset, shadowYOffset;
-        float shadowOpacity;
+        double shadowOpacity;
         int shadowFuzzyness;
+        int shadowSize;
+        bool intensifyActiveShadow;
         GLTexture* mShadowTexture;
     };
 
