@@ -16,7 +16,7 @@ License. See the file "COPYING" for the exact licensing terms.
 #undef KDE3_SUPPORT
 
 class QSpinBox;
-
+class QCheckBox;
 
 namespace KWin
 {
@@ -25,7 +25,7 @@ class ShadowEffectConfig : public KCModule
     {
     Q_OBJECT
     public:
-        ShadowEffectConfig(QWidget* parent = 0, const QStringList& args = QStringList());
+        explicit ShadowEffectConfig(QWidget* parent = 0, const QVariantList& args = QVariantList());
         ~ShadowEffectConfig();
 
         virtual void save();
@@ -37,6 +37,8 @@ class ShadowEffectConfig : public KCModule
         QSpinBox* mShadowYOffset;
         QSpinBox* mShadowOpacity;
         QSpinBox* mShadowFuzzyness;
+        QSpinBox* mShadowSize;
+        QCheckBox* mIntensifyActiveShadow;
     };
 
 } // namespace
