@@ -20,11 +20,13 @@ License. See the file "COPYING" for the exact licensing terms.
 namespace KWin
 {
 
+class CompositingPrefs;
+
 class KWinAdvancedCompositingOptions : public KDialog
 {
     Q_OBJECT
     public:
-        KWinAdvancedCompositingOptions(QWidget* parent, KSharedConfigPtr config);
+        KWinAdvancedCompositingOptions(QWidget* parent, KSharedConfigPtr config, CompositingPrefs* defaults);
         virtual ~KWinAdvancedCompositingOptions();
 
         void load();
@@ -33,13 +35,15 @@ class KWinAdvancedCompositingOptions : public KDialog
         void changed();
         void save();
         void compositingModeChanged();
+        void showConfirmDialog();
 
-    signals:
-        void configSaved();
+        void reinitKWinCompositing();
 
     private:
         KSharedConfigPtr mKWinConfig;
         Ui::KWinAdvancedCompositingOptions ui;
+        CompositingPrefs* mDefaultPrefs;
+        QMap<QString, QString> mPreviousConfig;
 };
 
 } // namespace
