@@ -15,14 +15,25 @@ License. See the file "COPYING" for the exact licensing terms.
 #include <kcmodule.h>
 
 #include <ksharedconfig.h>
+#include <ktemporaryfile.h>
 
 #include "ui_main.h"
+#include "compositingprefs.h"
+#include "ktimerdialog.h"
 
 class KPluginSelector;
+class QLabel;
 
 namespace KWin
 {
 
+class ConfirmDialog : public KTimerDialog
+{
+Q_OBJECT
+public:
+    ConfirmDialog();
+};
+
 class KWinCompositingConfig : public KCModule
     {
     Q_OBJECT
@@ -33,18 +44,32 @@ class KWinCompositingConfig : public KCModule
         virtual QString quickHelp() const;
 
     public slots:
+        virtual void compositingEnabled(bool enabled);
         virtual void showAdvancedOptions();
+        virtual void showConfirmDialog();
+        void currentTabChanged(int tab);
 
         virtual void load();
         virtual void save();
         virtual void defaults();
         void reparseConfiguration(const QByteArray&conf);
 
+        void loadGeneralTab();
+        void loadEffectsTab();
+        bool saveGeneralTab();
+        void saveEffectsTab();
+
         void configChanged();
+        void initEffectSelector();
 
     private:
         KSharedConfigPtr mKWinConfig;
         Ui::KWinCompositingConfig ui;
+        CompositingPrefs mDefaultPrefs;
+
+        QMap<QString, QString> mPreviousConfig;
+        KTemporaryFile mTmpConfigFile;
+        KSharedConfigPtr mTmpConfig;
     };
 
 } // namespace
