@@ -48,7 +48,6 @@
 #include <kdialog.h>
 #include <kglobal.h>
 #include <kprocess.h>
-#include <k3process.h>
 #include <QTabWidget>
 #include <QtDBus/QtDBus>
 
@@ -457,15 +456,12 @@ void KFocusConfig::load( void )
     k = cg.readEntry(KWIN_DELAYFOCUS_INTERVAL,750);
     setDelayFocusInterval(k);
 
-    key = cg.readEntry(KWIN_AUTORAISE);
-    setAutoRaise(key == "on");
-    key = cg.readEntry(KWIN_DELAYFOCUS);
-    setDelayFocus(key == "on");
-    key = cg.readEntry(KWIN_CLICKRAISE);
-    setClickRaise(key != "off");
+    setAutoRaise( cg.readEntry(KWIN_AUTORAISE, false));
+    setDelayFocus( cg.readEntry(KWIN_DELAYFOCUS, false));
+    setClickRaise( cg.readEntry(KWIN_CLICKRAISE, true));
     setAutoRaiseEnabled();      // this will disable/hide the auto raise delay widget if focus==click
     setDelayFocusEnabled();
-    
+
     setSeparateScreenFocus( cg.readEntry(KWIN_SEPARATE_SCREEN_FOCUS, true));
     // on by default for non click to focus policies
     setActiveMouseScreen( cg.readEntry(KWIN_ACTIVE_MOUSE_SCREEN, focusCombo->currentIndex() != 0 ));
@@ -506,20 +502,11 @@ void KFocusConfig::save( void )
     if (v <0) v = 0;
     cg.writeEntry(KWIN_DELAYFOCUS_INTERVAL,v);
 
-    if (autoRaiseOn->isChecked())
-        cg.writeEntry(KWIN_AUTORAISE, "on");
-    else
-        cg.writeEntry(KWIN_AUTORAISE, "off");
+    cg.writeEntry(KWIN_AUTORAISE, autoRaiseOn->isChecked());
 
-    if (delayFocusOn->isChecked())
-        cg.writeEntry(KWIN_DELAYFOCUS, "on");
-    else
-        cg.writeEntry(KWIN_DELAYFOCUS, "off");
+    cg.writeEntry(KWIN_DELAYFOCUS, delayFocusOn->isChecked());
 
-    if (clickRaiseOn->isChecked())
-        cg.writeEntry(KWIN_CLICKRAISE, "on");
-    else
-        cg.writeEntry(KWIN_CLICKRAISE, "off");
+    cg.writeEntry(KWIN_CLICKRAISE, clickRaiseOn->isChecked());
 
     cg.writeEntry(KWIN_SEPARATE_SCREEN_FOCUS, separateScreenFocus->isChecked());
     cg.writeEntry(KWIN_ACTIVE_MOUSE_SCREEN, activeMouseScreen->isChecked());
@@ -752,10 +739,7 @@ void KAdvancedConfig::save( void )
 
     KConfigGroup cg(config, "Windows");
     cg.writeEntry(KWIN_ANIMSHADE, animateShade->isChecked());
-    if (shadeHoverOn->isChecked())
-        cg.writeEntry(KWIN_SHADEHOVER, "on");
-    else
-        cg.writeEntry(KWIN_SHADEHOVER, "off");
+    cg.writeEntry(KWIN_SHADEHOVER, shadeHoverOn->isChecked());
 
     v = getShadeHoverInterval();
     if (v<0) v = 0;
@@ -889,7 +873,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, const KCompone
     minimizeAnimSlider->setValue( 0 );
     minimizeAnimSlider->setOrientation( Qt::Horizontal );
     minimizeAnimSlider->setTickPosition(QSlider::TicksBelow);
-    rLay->addWidget(minimizeAnimSlider,0,0,1,2);
+    rLay->addWidget(minimizeAnimSlider,0,1,1,2);
 
     connect(minimizeAnimOn, SIGNAL(toggled(bool)), this, SLOT(setMinimizeAnim(bool)));
     connect(minimizeAnimSlider, SIGNAL(valueChanged(int)), this, SLOT(setMinimizeAnimSpeed(int)));
@@ -991,7 +975,7 @@ KMovingConfig::KMovingConfig (bool _standAlone, KConfig *_config, const KCompone
     BrdrSnap->setSteps(1,10);
     WndwSnap->setWhatsThis( i18n("Here you can set the snap zone for windows, i.e."
                                     " the 'strength' of the magnetic field which will make windows snap to each other when"
-                                    " they're moved near another window.") );
+                                    " they are moved near another window.") );
 
     OverlapSnap=new QCheckBox(i18n("Snap windows onl&y when overlapping"),MagicBox);
     OverlapSnap->setWhatsThis( i18n("Here you can set that windows will be only"
