@@ -29,11 +29,14 @@ class Application : public  KApplication
     protected:
         bool x11EventFilter( XEvent * );
         bool notify( QObject* o, QEvent* e );
+        static void crashHandler(int signal);
     private slots:
         void lostSelection();
+        void resetCrashesCount();
 
     private:
         KWinSelectionOwner owner;
+        static int crashes;
     };
 
 } // namespace
