@@ -23,12 +23,12 @@ class PopupInfo : public QWidget
     {
     Q_OBJECT
     public:
-        PopupInfo( Workspace* ws, const char *name=0 );
+        explicit PopupInfo( Workspace* ws, const char *name=0 );
         ~PopupInfo();
 
         void reset();
         void hide();
-        void showInfo(QString infoString);
+        void showInfo(const QString &infoString);
 
         void reconfigure();
 
