@@ -67,6 +67,10 @@ Sources and other compositing managers:
 #include <sys/shm.h>
 #include <math.h>
 
+// turns on checks for opengl errors in various places (for easier finding of them)
+// normally only few of them are enabled
+//#define CHECK_GL_ERROR
+
 #ifdef HAVE_OPENGL
 
 namespace KWin
@@ -106,9 +110,11 @@ SceneOpenGL::SceneOpenGL( Workspace* ws )
         }
     initGLX();
     // check for FBConfig support
-    if( !hasGLXVersion( 1, 3 ) && !hasGLExtension( "GLX_SGIX_fbconfig" ))
+    if( !hasGLExtension( "GLX_SGIX_fbconfig" ) || !glXGetFBConfigAttrib || !glXGetFBConfigs ||
+            !glXGetVisualFromFBConfig || !glXCreatePixmap || !glXDestroyPixmap ||
+            !glXCreateWindow || !glXDestroyWindow )
         {
-        kDebug( 1212 ) << "GLX1.3 or GLX_SGIX_fbconfig missing";
+        kDebug( 1212 ) << "GLX_SGIX_fbconfig or required GLX functions missing";
         return; // error
         }
     if( !selectMode())
@@ -283,7 +289,7 @@ bool SceneOpenGL::initRenderingContext()
     KXErrorHandler errs;
     ctxbuffer = glXCreateNewContext( display(), fbcbuffer, GLX_RGBA_TYPE, NULL,
         direct_rendering ? GL_TRUE : GL_FALSE );
-    if( ctxbuffer == NULL || !glXMakeContextCurrent( display(), glxbuffer, glxbuffer, ctxbuffer )
+    if( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer )
         || errs.error( true ))
         { // failed
         if( !direct_rendering )
@@ -294,7 +300,7 @@ bool SceneOpenGL::initRenderingContext()
         glXDestroyContext( display(), ctxbuffer );
         direct_rendering = false; // try again
         ctxbuffer = glXCreateNewContext( display(), fbcbuffer, GLX_RGBA_TYPE, NULL, GL_FALSE );
-        if( ctxbuffer == NULL || !glXMakeContextCurrent( display(), glxbuffer, glxbuffer, ctxbuffer ))
+        if( ctxbuffer == NULL || !glXMakeCurrent( display(), glxbuffer, ctxbuffer ))
             {
             kDebug( 1212 ) << "Couldn't initialize rendering context";
             return false;
@@ -557,7 +563,13 @@ void SceneOpenGL::paint( QRegion damage, ToplevelList toplevels )
     glXWaitX();
     glPushMatrix();
     int mask = 0;
+#ifdef CHECK_GL_ERROR
+    checkGLError( "Paint1" );
+#endif
     paintScreen( &mask, &damage ); // call generic implementation
+#ifdef CHECK_GL_ERROR
+    checkGLError( "Paint2" );
+#endif
     glPopMatrix();
     ungrabXServer(); // ungrab before flushBuffer(), it may wait for vsync
     flushBuffer( mask, damage );
@@ -755,12 +767,6 @@ void SceneOpenGL::Texture::init()
 void SceneOpenGL::Texture::createTexture()
     {
     glGenTextures( 1, &mTexture );
-    glBindTexture( mTarget, mTexture );
-    if( hasGLVersion( 1, 4, 0 ))
-        {
-        // Lod bias makes the trilinear-filtered texture look a bit sharper
-        glTexEnvf( GL_TEXTURE_FILTER_CONTROL, GL_TEXTURE_LOD_BIAS, -1.0f );
-        }
     }
 
 void SceneOpenGL::Texture::discard()
@@ -834,6 +840,9 @@ QRegion SceneOpenGL::Texture::optimizeBindDamage( const QRegion& reg, int limit
 bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
     int depth, QRegion region )
     {
+#ifdef CHECK_GL_ERROR
+    checkGLError( "TextureLoad1" );
+#endif
     if( pix == None || size.isEmpty() || depth < 1 )
         return false;
     if( tfp_mode )
@@ -852,6 +861,9 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
         setDirty();
         }
 
+#ifdef CHECK_GL_ERROR
+    checkGLError( "TextureLoad2" );
+#endif
     if( tfp_mode )
         { // tfp mode, simply bind the pixmap to texture
         if( mTexture == None )
@@ -869,10 +881,16 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
             // the GLXPixmap will reference the X pixmap, so it will be freed automatically
             // when no longer needed
             bound_glxpixmap = glXCreatePixmap( display(), fbcdrawableinfo[ depth ].fbconfig, pix, attrs );
+#ifdef CHECK_GL_ERROR
+            checkGLError( "TextureLoadTFP1" );
+#endif
             findTarget();
             y_inverted = fbcdrawableinfo[ depth ].y_inverted ? true : false;
             can_use_mipmaps = fbcdrawableinfo[ depth ].mipmap ? true : false;
             glBindTexture( mTarget, mTexture );
+#ifdef CHECK_GL_ERROR
+            checkGLError( "TextureLoadTFP2" );
+#endif
             if( !options->glStrictBinding )
                 glXBindTexImageEXT( display(), bound_glxpixmap, GLX_FRONT_LEFT_EXT, NULL );
             }
@@ -892,6 +910,9 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
             type = GL_UNSIGNED_SHORT_5_6_5;
             }
         findTarget();
+#ifdef CHECK_GL_ERROR
+            checkGLError( "TextureLoadSHM1" );
+#endif
         if( mTexture == None )
             {
             createTexture();
@@ -925,6 +946,9 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
             XFreePixmap( display(), p );
             XFreeGC( display(), gc );
             }
+#ifdef CHECK_GL_ERROR
+        checkGLError( "TextureLoadSHM2" );
+#endif
         y_inverted = true;
         can_use_mipmaps = true;
 #endif
@@ -935,7 +959,7 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
         // not work (however, it does seem to work with nvidia)
         findTarget();
         GLXDrawable pixmap = glXCreatePixmap( display(), fbcdrawableinfo[ QX11Info::appDepth() ].fbconfig, pix, NULL );
-        glXMakeContextCurrent( display(), pixmap, pixmap, ctxdrawable );
+        glXMakeCurrent( display(), pixmap, ctxdrawable );
         if( last_pixmap != None )
             glXDestroyPixmap( display(), last_pixmap );
         // workaround for ATI - it leaks/crashes when the pixmap is destroyed immediately
@@ -968,11 +992,14 @@ bool SceneOpenGL::Texture::load( const Pixmap& pix, const QSize& size,
         glXWaitGL();
         if( db )
             glDrawBuffer( GL_BACK );
-        glXMakeContextCurrent( display(), glxbuffer, glxbuffer, ctxbuffer );
+        glXMakeCurrent( display(), glxbuffer, ctxbuffer );
         glBindTexture( mTarget, mTexture );
         y_inverted = false;
         can_use_mipmaps = true;
         }
+#ifdef CHECK_GL_ERROR
+    checkGLError( "TextureLoad0" );
+#endif
     return true;
     }
 
@@ -1008,10 +1035,19 @@ void SceneOpenGL::Texture::bind()
         glXBindTexImageEXT( display(), bound_glxpixmap, GLX_FRONT_LEFT_EXT, NULL );
         }
     enableFilter();
+    if( hasGLVersion( 1, 4, 0 ))
+        {
+        // Lod bias makes the trilinear-filtered texture look a bit sharper
+        glTexEnvf( GL_TEXTURE_FILTER_CONTROL, GL_TEXTURE_LOD_BIAS, -1.0f );
+        }
     }
 
 void SceneOpenGL::Texture::unbind()
     {
+    if( hasGLVersion( 1, 4, 0 ))
+        {
+        glTexEnvf( GL_TEXTURE_FILTER_CONTROL, GL_TEXTURE_LOD_BIAS, 0.0f );
+        }
     if( tfp_mode && options->glStrictBinding )
         {
         assert( bound_glxpixmap != None );
@@ -1177,7 +1213,7 @@ void SceneOpenGL::Window::renderQuads( int mask, const QRegion& region, const Wi
     delete[] texcoords;
     }
 
-void SceneOpenGL::Window::prepareStates( float opacity, float brightness, float saturation, GLShader* shader )
+void SceneOpenGL::Window::prepareStates( double opacity, double brightness, double saturation, GLShader* shader )
     {
     if(shader)
         prepareShaderRenderStates( opacity, brightness, saturation, shader );
@@ -1185,7 +1221,7 @@ void SceneOpenGL::Window::prepareStates( float opacity, float brightness, float
         prepareRenderStates( opacity, brightness, saturation );
     }
 
-void SceneOpenGL::Window::prepareShaderRenderStates( float opacity, float brightness, float saturation, GLShader* shader )
+void SceneOpenGL::Window::prepareShaderRenderStates( double opacity, double brightness, double saturation, GLShader* shader )
     {
     // setup blending of transparent windows
     glPushAttrib( GL_ENABLE_BIT );
@@ -1200,7 +1236,7 @@ void SceneOpenGL::Window::prepareShaderRenderStates( float opacity, float bright
     shader->setUniform("brightness", (float)brightness);
     }
 
-void SceneOpenGL::Window::prepareRenderStates( float opacity, float brightness, float saturation )
+void SceneOpenGL::Window::prepareRenderStates( double opacity, double brightness, double saturation )
     {
     // setup blending of transparent windows
     glPushAttrib( GL_ENABLE_BIT );
@@ -1325,7 +1361,7 @@ void SceneOpenGL::Window::prepareRenderStates( float opacity, float brightness,
         }
     }
 
-void SceneOpenGL::Window::restoreStates( float opacity, float brightness, float saturation, GLShader* shader )
+void SceneOpenGL::Window::restoreStates( double opacity, double brightness, double saturation, GLShader* shader )
     {
     if(shader)
         restoreShaderRenderStates( opacity, brightness, saturation, shader );
@@ -1333,7 +1369,7 @@ void SceneOpenGL::Window::restoreStates( float opacity, float brightness, float
         restoreRenderStates( opacity, brightness, saturation );
     }
 
-void SceneOpenGL::Window::restoreShaderRenderStates( float opacity, float brightness, float saturation, GLShader* shader )
+void SceneOpenGL::Window::restoreShaderRenderStates( double opacity, double brightness, double saturation, GLShader* shader )
     {
     Q_UNUSED( opacity );
     Q_UNUSED( brightness );
@@ -1342,7 +1378,7 @@ void SceneOpenGL::Window::restoreShaderRenderStates( float opacity, float bright
     glPopAttrib();  // ENABLE_BIT
     }
 
-void SceneOpenGL::Window::restoreRenderStates( float opacity, float brightness, float saturation )
+void SceneOpenGL::Window::restoreRenderStates( double opacity, double brightness, double saturation )
     {
     if( opacity != 1.0 || saturation != 1.0 || brightness != 1.0f )
         {
