@@ -394,7 +394,7 @@ void SceneXrender::Window::discardAlpha()
     }
 
 // Create XRender picture for the alpha mask.
-Picture SceneXrender::Window::alphaMask( float opacity )
+Picture SceneXrender::Window::alphaMask( double opacity )
     {
     if( isOpaque() && opacity == 1.0 )
         return None;
@@ -453,7 +453,7 @@ void SceneXrender::Window::performPaint( int mask, QRegion region, WindowPaintDa
     if( pic == None ) // The render format can be null for GL and/or Xv visuals
         return;
     // set picture filter
-    if( options->smoothScale > 0 ) // only when forced, it's slow
+    if( options->xrenderSmoothScale ) // only when forced, it's slow
         {
         if( mask & PAINT_WINDOW_TRANSFORMED )
             filter = ImageFilterGood;
@@ -469,8 +469,8 @@ void SceneXrender::Window::performPaint( int mask, QRegion region, WindowPaintDa
     int y = toplevel->y();
     int width = toplevel->width();
     int height = toplevel->height();
-    float xscale = 1;
-    float yscale = 1;
+    double xscale = 1;
+    double yscale = 1;
     transformed_shape = shape();
     if( mask & PAINT_WINDOW_TRANSFORMED )
         {
