@@ -135,6 +135,7 @@ Workspace::Workspace( bool restore )
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject("/KWin", this);
     dbus.connect(QString(), "/KWin", "org.kde.KWin", "reloadConfig", this, SLOT(slotReloadConfig()));
+    dbus.connect(QString(), "/KWin", "org.kde.KWin", "reinitCompositing", this, SLOT(slotReinitCompositing()));
     _self = this;
     mgr = new PluginMgr;
     QX11Info info;
@@ -441,8 +442,8 @@ Workspace::~Workspace()
         // No removeClient() is called, it does more than just removing.
         // However, remove from some lists to e.g. prevent performTransiencyCheck()
         // from crashing.
-        clients.remove( *it );
-        desktops.remove( *it );
+        clients.removeAll( *it );
+        desktops.removeAll( *it );
         }
     for( UnmanagedList::ConstIterator it = unmanaged.begin();
          it != unmanaged.end();
@@ -1049,6 +1050,20 @@ void Workspace::slotReconfigure()
         }
     }
 
+void Workspace::slotReinitCompositing()
+    {
+    // Reparse config. Config options will be reloaded by setupCompositing()
+    KGlobal::config()->reparseConfiguration();
+    options->updateSettings();
+
+    // Stop any current compositing
+    finishCompositing();
+    // And start new one
+    setupCompositing();
+    if( effects ) // setupCompositing() may fail
+        effects->reconfigure();
+    }
+
 void Workspace::loadDesktopSettings()
     {
     KSharedConfig::Ptr c = KGlobal::config();
@@ -1115,11 +1130,11 @@ void Workspace::saveDesktopSettings()
 QStringList Workspace::configModules(bool controlCenter)
     {
     QStringList args;
-    args <<  "kde-kwindecoration.desktop";
+    args <<  "kwindecoration";
     if (controlCenter)
-        args << "kde-kwinoptions.desktop";
+        args << "kwinoptions";
     else if (KAuthorized::authorizeControlModule("kde-kwinoptions.desktop"))
-        args  << "kwinactions" << "kwinfocus" <<  "kwinmoving" << "kwinadvanced" << "kwinrules" << "kwincompositing" << "kwineffects";
+        args  << "kwinactions" << "kwinfocus" <<  "kwinmoving" << "kwinadvanced" << "kwinrules" << "kwincompositing";
     return args;
     }
 
@@ -1630,7 +1645,7 @@ void Workspace::checkActiveScreen( const Client* c )
 
 // called e.g. when a user clicks on a window, set active screen to be the screen
 // where the click occurred
-void Workspace::setActiveScreenMouse( QPoint mousepos )
+void Workspace::setActiveScreenMouse( const QPoint &mousepos )
     {
     if( !options->xineramaEnabled )
         return;
@@ -1644,7 +1659,7 @@ QRect Workspace::screenGeometry( int screen ) const
     return qApp->desktop()->screenGeometry( screen );
     }
 
-int Workspace::screenNumber( QPoint pos ) const
+int Workspace::screenNumber( const QPoint &pos ) const
     {
     if( !options->xineramaEnabled )
         return 0;
@@ -1855,7 +1870,7 @@ WId Workspace::getMouseEmulationWindow()
 /*!
   Sends a faked mouse event to the specified window. Returns the new button state.
  */
-unsigned int Workspace::sendFakedMouseEvent( QPoint pos, WId w, MouseEmulation type, int button, unsigned int state )
+unsigned int Workspace::sendFakedMouseEvent( const QPoint &pos, WId w, MouseEmulation type, int button, unsigned int state )
     {
     if ( !w )
         return state;
