@@ -3,8 +3,9 @@
  *   Copyright 2007 by Riccardo Iaconelli <riccardo@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
+ *   it under the terms of the GNU Library General Public License as
+ *   published by the Free Software Foundation; either version 2, or
+ *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,6 +43,7 @@
 #include <KIconLoader>
 
 #include "plasma/configxml.h"
+#include "plasma/containment.h"
 #include "plasma/corona.h"
 #include "plasma/dataenginemanager.h"
 #include "plasma/package.h"
@@ -54,7 +56,7 @@
 #include "plasma/widgets/widget.h"
 #include "plasma/widgets/lineedit.h"
 #include "plasma/widgets/pushbutton.h"
-#include "plasma/widgets/vboxlayout.h"
+#include "plasma/widgets/boxlayout.h"
 
 //#define DYNAMIC_SHADOWS
 namespace Plasma
@@ -105,10 +107,6 @@ public:
     void init(Applet* applet)
     {
         applet->setZValue(100);
-        //these lines fix behaviour somewhat with update()s after resize in qt 4.3.0,
-        //but the issues are fixed in 4.3.1 and this breaks shadows.
-        //applet->setFlag(QGraphicsItem::ItemClipsToShape, false);
-        //applet->setFlag(QGraphicsItem::ItemClipsChildrenToShape, false);
         kioskImmutable = applet->globalConfig().isImmutable() ||
                          applet->config().isImmutable();
         applet->setImmutable(kioskImmutable);
@@ -174,6 +172,13 @@ public:
 
     void paintBackground(QPainter* p2, Applet* q)
     {
+        if (q->formFactor() != Plasma::Planar) {
+            // we don't paint special backgrounds for other form factors
+            // if that changes in the future, this method is where such
+            // background painting code should be added
+            return;
+        }
+
         QSize contents = contentSize(q).toSize();
         const int contentWidth = contents.width();
         const int contentHeight = contents.height();
@@ -196,7 +201,9 @@ public:
         const int bottomOffset = contentHeight;
         const int contentTop = 0;
         const int contentLeft = 0;
-        if (!cachedBackground || cachedBackground->size() != QSize(leftWidth + contentWidth + rightWidth, topHeight + contentHeight + bottomHeight)) {
+        QSize s = QSize(leftWidth + contentWidth + rightWidth,
+                        topHeight + contentHeight + bottomHeight);
+        if (!cachedBackground || cachedBackground->size() != s) {
             delete cachedBackground;
             cachedBackground = new QPixmap(leftWidth + contentWidth + rightWidth, topHeight + contentHeight + bottomHeight);
             cachedBackground->fill(Qt::transparent);
@@ -205,50 +212,64 @@ public:
             p.setCompositionMode(QPainter::CompositionMode_Source);
             p.setRenderHint(QPainter::SmoothPixmapTransform);
 
-            background->paint(&p, QRect(leftOffset,  topOffset,    leftWidth,  topHeight),    "topleft");
-            background->paint(&p, QRect(rightOffset, topOffset,    rightWidth, topHeight),    "topright");
-            background->paint(&p, QRect(leftOffset,  bottomOffset, leftWidth,  bottomHeight), "bottomleft");
+            //FIXME: This is a hack to fix a drawing problems with svg files where a thin transparent border is drawn around the svg image.
+            //       the transparent border around the svg seems to vary in size depending on the size of the svg and as a result increasing the 
+	    //	     svn image by 2 all around didn't resolve the issue. For now it resizes based on the border size.
+
+            background->resize(contentWidth, contentHeight);
+            background->paint(&p, QRect(contentLeft-leftWidth, contentTop-topHeight, contentWidth+leftWidth*2, contentHeight+topHeight*2), "center");
+            background->resize();
+
+            background->paint(&p, QRect(leftOffset, topOffset, leftWidth, topHeight), "topleft");
+            background->paint(&p, QRect(rightOffset, topOffset,rightWidth, topHeight), "topright");
+            background->paint(&p, QRect(leftOffset, bottomOffset, leftWidth, bottomHeight), "bottomleft");
             background->paint(&p, QRect(rightOffset, bottomOffset, rightWidth, bottomHeight), "bottomright");
 
-            QPixmap left(leftWidth, leftHeight);
-            left.fill(Qt::transparent);
-            {
-                QPainter sidePainter(&left);
-                sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                background->paint(&sidePainter, QPoint(0, 0), "left");
-            }
-            p.drawTiledPixmap(QRect(leftOffset, contentTop, leftWidth, contentHeight), left);
+            if (stretchBackgroundBorders) {
+                background->paint(&p, QRect(leftOffset, contentTop, leftWidth, contentHeight), "left");
+                background->paint(&p, QRect(rightOffset, contentTop, rightWidth, contentHeight), "right");
+                background->paint(&p, QRect(contentLeft, topOffset, contentWidth, topHeight), "top");
+                background->paint(&p, QRect(contentLeft, bottomOffset, contentWidth, bottomHeight), "bottom");
+            } else {
+                QPixmap left(leftWidth, leftHeight);
+                left.fill(Qt::transparent);
+                {
+                    QPainter sidePainter(&left);
+                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
+                    background->paint(&sidePainter, QPoint(0, 0), "left");
+                }
+                p.drawTiledPixmap(QRect(leftOffset, contentTop, leftWidth, contentHeight), left);
 
-            QPixmap right(rightWidth, leftHeight);
-            right.fill(Qt::transparent);
-            {
-                QPainter sidePainter(&right);
-                sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                background->paint(&sidePainter, QPoint(0, 0), "right");
-            }
-            p.drawTiledPixmap(QRect(rightOffset, contentTop, rightWidth, contentHeight), right);
+                QPixmap right(rightWidth, leftHeight);
+                right.fill(Qt::transparent);
+                {
+                    QPainter sidePainter(&right);
+                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
+                    background->paint(&sidePainter, QPoint(0, 0), "right");
+                }
+                p.drawTiledPixmap(QRect(rightOffset, contentTop, rightWidth, contentHeight), right);
 
-            QPixmap top(topWidth, topHeight);
-            top.fill(Qt::transparent);
-            {
-                QPainter sidePainter(&top);
-                sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                background->paint(&sidePainter, QPoint(0, 0), "top");
-            }
-            p.drawTiledPixmap(QRect(contentLeft, topOffset, contentWidth, topHeight), top);
+                QPixmap top(topWidth, topHeight);
+                top.fill(Qt::transparent);
+                {
+                    QPainter sidePainter(&top);
+                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
+                    background->paint(&sidePainter, QPoint(0, 0), "top");
+                }
+                p.drawTiledPixmap(QRect(contentLeft, topOffset, contentWidth, topHeight), top);
 
-            QPixmap bottom(topWidth, bottomHeight);
-            bottom.fill(Qt::transparent);
-            {
-                QPainter sidePainter(&bottom);
-                sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-                background->paint(&sidePainter, QPoint(0, 0), "bottom");
+                QPixmap bottom(topWidth, bottomHeight);
+                bottom.fill(Qt::transparent);
+                {
+                    QPainter sidePainter(&bottom);
+                    sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
+                    background->paint(&sidePainter, QPoint(0, 0), "bottom");
+                }
+                p.drawTiledPixmap(QRect(contentLeft, bottomOffset, contentWidth, bottomHeight), bottom);
             }
-            p.drawTiledPixmap(QRect(contentLeft, bottomOffset, contentWidth, bottomHeight), bottom);
 
-            background->paint(&p, QRect(contentLeft, contentTop, contentWidth + 1, contentHeight + 1), "center");
-            p.end();
         }
+
         p2->drawPixmap(leftOffset, topOffset, *cachedBackground);
     }
 
@@ -300,7 +321,7 @@ public:
     {
         if (!background) {
             top = left = right = bottom = 0;
-        } else { 
+        } else {
             top = background->elementSize("top").height();
             left = background->elementSize("left").width();
             right = background->elementSize("right").width();
@@ -319,6 +340,7 @@ public:
     QStringList loadedEngines;
     static uint s_maxAppletId;
     Plasma::Svg *background;
+    bool stretchBackgroundBorders;
     Plasma::LineEdit *failureText;
     ScriptEngine* scriptEngine;
     ConfigXml* configXml;
@@ -348,7 +370,7 @@ Applet::Applet(QObject* parentObject, const QVariantList& args)
                      args.count() > 1 ? args[1].toInt() : 0))
 {
     d->init(this);
-    // the brain damage seen in the initialization list is due to the 
+    // the brain damage seen in the initialization list is due to the
     // inflexibility of KService::createInstance
 }
 
@@ -367,6 +389,10 @@ Applet::~Applet()
     delete d;
 }
 
+void Applet::init()
+{
+}
+
 uint Applet::id() const
 {
     return d->appletId;
@@ -377,6 +403,24 @@ KConfigGroup Applet::config() const
     return KConfigGroup(d->config(), "General");
 }
 
+void Applet::save(KConfigGroup* group) const
+{
+    group->writeEntry("plugin", pluginName());
+    group->writeEntry("geometry", QRect(pos().toPoint(), boundingRect().size().toSize()));
+
+    Containment* c = containment();
+    if (c) {
+        group->writeEntry("containment", c->id());
+    }
+
+    saveState(group);
+}
+
+void Applet::saveState(KConfigGroup* group) const
+{
+    Q_UNUSED(group)
+}
+
 KConfigGroup Applet::config(const QString& group) const
 {
     KConfigGroup cg = config();
@@ -435,15 +479,15 @@ const Package* Applet::package() const
     return d->package;
 }
 
-void Applet::updateConstraints()
+void Applet::updateConstraints(Plasma::Constraints constraints)
 {
-    constraintsUpdated();
+    constraintsUpdated(constraints);
     setShadowShown(formFactor() == Planar);
 }
 
-void Applet::constraintsUpdated()
+void Applet::constraintsUpdated(Plasma::Constraints constraints)
 {
-    kDebug() << "Applet::constraintsUpdate(): constraints are FormFactor: " << formFactor() << ", Location: " << location();
+    kDebug() << constraints << "constraints are FormFactor: " << formFactor() << ", Location: " << location();
 }
 
 QString Applet::name() const
@@ -526,6 +570,7 @@ void Applet::setDrawStandardBackground(bool drawBackground)
         if (!d->background) {
             prepareGeometryChange();
             d->background = new Plasma::Svg("widgets/background");
+            d->stretchBackgroundBorders = d->background->elementExists("hint-stretch-borders");
         }
     } else if (d->background) {
         prepareGeometryChange();
@@ -568,7 +613,7 @@ void Applet::setFailedToLaunch(bool failed, const QString& reason)
 
     if (failed) {
         setDrawStandardBackground(true);
-        Layout* failureLayout = new VBoxLayout(this);
+        Layout* failureLayout = new BoxLayout(BoxLayout::TopToBottom,this);
         d->failureText = new LineEdit(this, scene());
         d->failureText->setFlags(0);
         d->failureText->setHtml(visibleFailureText(reason));
@@ -598,7 +643,7 @@ void Applet::setNeedsConfiguring(bool needsConfig)
 
     if (needsConfig) {
         setDrawStandardBackground(true);
-        Layout* layout = new VBoxLayout(this);
+        Layout* layout = new BoxLayout(BoxLayout::TopToBottom,this);
         PushButton* button = new PushButton(this);
         button->setText(i18n("Configure..."));
         connect(button, SIGNAL(clicked()), this, SLOT(performSetupConfig()));
@@ -628,7 +673,10 @@ QRectF Applet::boundingRect() const
     int bottom;
 
     d->getBorderSize(left,top,right,bottom);
-    
+
+
+    //qDebug() << "Background , Border size" << d->background << left << top << right << bottom;
+
     return rect.adjusted(-left,-top,right,bottom);
 }
 
@@ -641,7 +689,9 @@ QSizeF Applet::sizeHint() const
 
     d->getBorderSize(left,top,right,bottom);
 
-    return contentSize() + QSizeF(left+right,top+bottom);
+    //qDebug() << "Applet content size hint: " << contentSizeHint();
+
+    return contentSizeHint() + QSizeF(left+right,top+bottom);
 }
 
 QList<QAction*> Applet::contextActions()
@@ -681,7 +731,7 @@ QColor Applet::color() const
     }
 }
 
-void Applet::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void Applet::paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     Q_UNUSED(widget)
     if (d->shadow && d->shadow->shadowedSize() != boundingRect().size()) {
@@ -706,7 +756,7 @@ void Applet::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QW
         //TODO: make pretty.
         painter->setBrush(QBrush(color(), Qt::SolidPattern));
         painter->drawRoundRect(boundingRect());
-        int iconDim = KIconLoader::global()->currentSize(K3Icon::Desktop);
+        int iconDim = KIconLoader::global()->currentSize(KIconLoader::Desktop);
         qreal midX = (boundingRect().width() / 2) - (iconDim / 2);
         qreal midY = (boundingRect().height() / 2) - (iconDim / 2);
         KIcon ico(icon());
@@ -729,23 +779,43 @@ void Applet::paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *o
 
 FormFactor Applet::formFactor() const
 {
-    if (!scene()) {
+    Containment* c = containment();
+
+    if (!c) {
         return Plasma::Planar;
     }
 
-    return static_cast<Corona*>(scene())->formFactor();
+    return c->formFactor();
+}
+
+Containment* Applet::containment() const
+{
+    return dynamic_cast<Containment*>(parentItem());
 }
 
 Location Applet::location() const
 {
-    if (!scene()) {
+    Containment* c = containment();
+
+    if (!c) {
         return Plasma::Desktop;
     }
 
-    return static_cast<Corona*>(scene())->location();
+    return c->location();
 }
 
 QSizeF Applet::contentSize() const
+{
+    int top , left , right , bottom;
+    d->getBorderSize(left,top,right,bottom);
+
+    // qDebug() << "Geometry size: " << geometry().size();
+    // qDebug() << "Borders: " << left << top << right << bottom;
+
+    return geometry().size() - QSizeF(left+right,top+bottom);
+}
+
+QSizeF Applet::contentSizeHint() const
 {
     if (layout()) {
         return layout()->sizeHint();
@@ -934,7 +1004,7 @@ Applet* Applet::loadApplet(const QString& appletName, uint appletId, const QVari
     QVariantList allArgs;
     allArgs << offers.first()->storageId() << appletId << args;
     QString error;
-    Applet* applet = KService::createInstance<Plasma::Applet>(offers.first(), 0, allArgs, &error);
+    Applet* applet = offers.first()->createInstance<Plasma::Applet>(0, allArgs, &error);
 
     if (!applet) {
         kDebug() << "Couldn't load applet \"" << appletName << "\"! reason given: " << error;
@@ -1017,6 +1087,44 @@ QVariant Applet::itemChange(GraphicsItemChange change, const QVariant &value)
     return QGraphicsItem::itemChange(change, value);
 }
 
+void Applet::setGeometry(const QRectF& geometry)
+{
+    if (size() != geometry.size()) {
+        prepareGeometryChange();
+        qreal width = qBound(minimumSize().width(), geometry.size().width(), maximumSize().width());
+        qreal height = qBound(minimumSize().height(), geometry.size().height(), maximumSize().height());
+
+        setSize(QSizeF(width, height));
+
+        if (layout()) {
+            layout()->setGeometry(QRectF(QPoint(0, 0), contentSize()));
+        }
+    }
+
+    setPos(geometry.topLeft());
+    update();
+}
+
+void Applet::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
+{
+    //kDebug() << "context menu event!";
+    if (!scene()) {
+        return;
+    }
+
+    Applet* containment = dynamic_cast<Plasma::Applet*>(topLevelItem());
+
+    if (!containment) {
+        Widget::contextMenuEvent(event);
+        return;
+    }
+
+    // we want to pass up the context menu event to the Containment at
+    // this point
+    containment->contextMenuEvent(event);
+    return;
+}
+
 } // Plasma namespace
 
 #include "applet.moc"
