@@ -3,8 +3,9 @@
  *   Copyright 2007 by Riccardo Iaconelli <riccardo@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
+ *   it under the terms of the GNU Library General Public License as
+ *   published by the Free Software Foundation; either version 2, or
+ *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,6 +35,7 @@
 namespace Plasma
 {
 
+class Containment;
 class DataEngine;
 class Package;
 
@@ -53,7 +55,7 @@ class Package;
  *
  * See techbase.kde.org for tutorial on writing Applets using this class.
  */
-class PLASMA_EXPORT Applet : public Widget 
+class PLASMA_EXPORT Applet : public Widget
 {
     Q_OBJECT
 //    Q_PROPERTY( QRectF maxSizeHint READ maxSizeHint )
@@ -65,6 +67,7 @@ class PLASMA_EXPORT Applet : public Widget
     Q_PROPERTY( bool failedToLaunch READ failedToLaunch WRITE setFailedToLaunch )
     Q_PROPERTY( bool needsConfiguring READ needsConfiguring WRITE setNeedsConfiguring )
     Q_PROPERTY( QRectF boundingRect READ boundingRect )
+    Q_PROPERTY( QRectF geometry READ geometry WRITE setGeometry )
 
     public:
         typedef QList<Applet*> List;
@@ -95,6 +98,14 @@ class PLASMA_EXPORT Applet : public Widget
 
         ~Applet();
 
+        /**
+         * This method is called once the applet is loaded and added to a Corona.
+         * If the applet requires a QGraphicsScene or has an particularly intensive
+         * set of initialization routines to go through, consider implementing it
+         * in this method instead of the contsructor.
+         **/
+        virtual void init();
+
         /**
          * @return the id of this applet
          */
@@ -118,6 +129,11 @@ class PLASMA_EXPORT Applet : public Widget
          **/
         KConfigGroup config(const QString& group) const;
 
+        /**
+         * Saves state information about this applet.
+         **/
+        void save(KConfigGroup* group) const;
+
         /**
          * Returns a KConfigGroup object to be shared by all applets of this
          * type.
@@ -166,8 +182,10 @@ class PLASMA_EXPORT Applet : public Widget
          * Called when any of the geometry constraints have been updated.
          * This method calls constraintsUpdated, which may be reimplemented,
          * once the Applet has been prepared for updating the constraints.
+         *
+         * @param constraints the type of constraints that were updated
          */
-        void updateConstraints();
+        void updateConstraints(Plasma::Constraints constraints = Plasma::AllConstraints);
 
         /**
          * Called when any of the geometry constraints have been updated.
@@ -178,70 +196,54 @@ class PLASMA_EXPORT Applet : public Widget
          * Do not call update() from this method; an update() will be triggered
          * at the appropriate time for the applet.
          *
+         * @param constraints the type of constraints that were updated
          * @property constraint
          */
-        virtual void constraintsUpdated();
+        virtual void constraintsUpdated(Plasma::Constraints constraints);
 
         /**
          * Returns the current form factor the applet is being displayed in.
          *
          * @see Plasma::FormFactor
          */
-        FormFactor formFactor() const;
+        virtual FormFactor formFactor() const;
 
         /**
          * Returns the location of the scene which is displaying applet.
          *
          * @see Plasma::Location
          */
-        Location location() const;
-
-        /**
-         * Returns a maximum size hint based on the Corona's space availability.
-         *
-         * An applet may choose to violate this size hint, but should try and
-         * respect it as much as possible.
-         */
-//        QRectF maxSizeHint() const;
+        virtual Location location() const;
 
         /**
          * Returns the area within which contents can be painted. If there is no
-         * background, then this is equivalent to boundingRect().
-         *
-         * Applets should implement contentSize() to tell Plasma::Applet how
-         * much space they need.
-         *
-         * When drawing to the applet in the paintInterface() method, you can
-         * use the QRect passed to that function.  Outside paintInterface(), for
-         * example when positioning a Plasma::Widget, you can assume your drawing
-         * area has (0,0) at the top left and is the size of contentSize().
-         *
-         * If drawStandardBackground() == true, enough space will reserved
-         * within the borders for the content, and boundingRect() will the
-         * total size of the applet, including borders.
-         *
-         * If the applet has not asked Plasma::Applet to draw the default
-         * background, boundingRect().size() == contentSize(), and
-         * boundingRect().topLeft() == QPointF(0,0).  Also, such applets will
-         * not break if they implement boundingRect() instead.
-         *
-         * Note that if the value returned by contentSize() (and hence
-         * boundingRect()) changes for any reason, you should call
-         * prepareGeometryChange() to notify the Corona.
+         * background, then this is equivalent to boundingRect().size()
          **/
-        virtual QSizeF contentSize() const;
+        QSizeF contentSize() const;
 
         /**
-         * Returns a list of all known applets in a hash keyed by a unique
-         * identifier for each applet.
+         * Returns an ideal size for the applet's content.
+         * Applets can re-implement this to provide a suitable size based
+         * on their contents.
+         *
+         * Unlike sizeHint() , contentSizeHint() does not include the
+         * size of any borders surrounding the content area.
+         *
+         * The default implementation returns the sizeHint() of the applet's
+         * layout if it has one, or a null size otherwise.
+         */
+        virtual QSizeF contentSizeHint() const;
+
+        /**
+         * Returns a list of all known applets.
          *
          * @param category Only applets matchin this category will be returned.
          *                 Useful in conjunction with knownCategories.
-         *                 If "Misc" is passed in, then applets without a 
+         *                 If "Misc" is passed in, then applets without a
          *                 Categories= entry are also returned.
          *                 If an empty string is passed in, all applets are
          *                 returned.
-         * @param parentApp the application to filter applets on. Uses the 
+         * @param parentApp the application to filter applets on. Uses the
          *                  X-KDE-ParentApp entry (if any) in the plugin info.
          *                  The default value of QString() will result in a
          *                  list containing only applets not specifically
@@ -252,8 +254,7 @@ class PLASMA_EXPORT Applet : public Widget
                                               const QString &parentApp = QString());
 
         /**
-         * Returns a list of all known applets associated with a certain mimetype in a hash keyed by a unique
-         * identifier for each applet
+         * Returns a list of all known applets associated with a certain mimetype.
          *
          * @return list of applets
          **/
@@ -263,7 +264,7 @@ class PLASMA_EXPORT Applet : public Widget
          * Returns a list of all the categories used by
          * installed applets.
          *
-         * @param parentApp the application to filter applets on. Uses the 
+         * @param parentApp the application to filter applets on. Uses the
          *                  X-KDE-ParentApp entry (if any) in the plugin info.
          *                  The default value of QString() will result in a
          *                  list containing only applets not specifically
@@ -377,7 +378,7 @@ class PLASMA_EXPORT Applet : public Widget
          **/
         bool isImmutable() const;
 
-        /** 
+        /**
          * Sets whether or not this applet is immutable or not.
          *
          * @arg immutable true if this applet should not be changeable
@@ -420,7 +421,7 @@ class PLASMA_EXPORT Applet : public Widget
         void setFailedToLaunch(bool failed, const QString& reason = QString());
 
         /**
-         * @return true if the applet currently needs to be configured, 
+         * @return true if the applet currently needs to be configured,
          *         otherwise, false
          */
         bool needsConfiguring() const;
@@ -470,6 +471,20 @@ class PLASMA_EXPORT Applet : public Widget
          */
         bool isShadowShown() const;
 
+        // reimplemented from LayoutItem
+        // value is the same as contentSizeHint() if drawStandardBackground() is false
+        // or contentSizeHint() plus the size of the border otherwise.
+        virtual QSizeF sizeHint() const;
+
+        /**
+        * Sets the geometry of this Applet.
+        */
+        /**
+        * Sets the geometry of this Plasma::Applet
+        * @param geometry the geometry to apply to this Plasma::Applet.
+        */
+        void setGeometry(const QRectF &geometry);
+
     Q_SIGNALS:
         /**
          * Emitted when the applet needs to take (or lose) keyboard focus.
@@ -493,6 +508,12 @@ class PLASMA_EXPORT Applet : public Widget
         void destroy();
 
     protected:
+        /**
+         * Called when a request to save the state of the applet is made
+         * during runtime
+         **/
+        virtual void saveState(KConfigGroup* config) const;
+
         /**
          * Returns the name of the applet.
          *
@@ -545,15 +566,20 @@ class PLASMA_EXPORT Applet : public Widget
          **/
         bool eventFilter( QObject *o, QEvent *e );
 
+        /**
+         * Reimplemented from QGraphicsItem
+         */
+        void contextMenuEvent(QGraphicsSceneContextMenuEvent *contextMenuEvent);
+
         /**
          * @internal for adjusting the shadow
          */
         QVariant itemChange(GraphicsItemChange change, const QVariant &value);
 
-        // reimplemented from LayoutItem
-        // value is the same as contentSize() if drawStandardBackground() is false
-        // or contentSize() plus the size of the border otherwise. 
-        virtual QSizeF sizeHint() const;
+        /**
+         * @return the Containment, if any, this applet belongs to
+         **/
+        Containment* containment() const;
 
     protected Q_SLOTS:
         /**
@@ -567,7 +593,7 @@ class PLASMA_EXPORT Applet : public Widget
         /**
          * Reimplemented from QGraphicsItem
          **/
-        void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
+        void paintWidget(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
 
         class Private;
         Private* const d;
