@@ -5,8 +5,9 @@
  *   Copyright 2006-2007 Fredrik Höglund <fredrik@kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License version 2 as
- *   published by the Free Software Foundation
+ *   it under the terms of the GNU Library General Public License as
+ *   published by the Free Software Foundation; either version 2, or
+ *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,11 +37,9 @@
 #include <private/qwindowsurface_p.h>
 #endif
 
-#include <KImageEffect>
 #include <KIconEffect>
 #include <KIconLoader>
 #include <KIcon>
-#include <K3Icon>
 #include <KUrl>
 #include <KRun>
 #include <KMimeType>
@@ -535,8 +534,8 @@ QPixmap Icon::Private::decoration(const QStyleOptionGraphicsItem *option) const
             // Note that in KIconLoader terminology, active = hover.
             // ### We're assuming that the icon group is desktop/filemanager, since this
             //     is KFileItemDelegate.
-            if (effect->hasEffect(K3Icon::Desktop, K3Icon::ActiveState)) {
-                result = effect->apply(result, K3Icon::Desktop, K3Icon::ActiveState);
+            if (effect->hasEffect(KIconLoader::Desktop, KIconLoader::ActiveState)) {
+                result = effect->apply(result, KIconLoader::Desktop, KIconLoader::ActiveState);
             }
         }
     }
@@ -993,6 +992,11 @@ QSizeF Icon::sizeHint() const
     return d->size;
 }
 
+Qt::Orientations Icon::expandingDirections() const
+{
+    return 0;
+}
+
 /*
 QSizeF Icon::sizeHint() const
 {
