@@ -37,30 +37,20 @@ class DesktopView : public QGraphicsView
     Q_OBJECT
 
 public:
-    DesktopView(QWidget *parent);
+    DesktopView(QWidget *parent, int screen = -1);
     ~DesktopView();
 
 public slots:
     void zoomIn();
     void zoomOut();
-    void launchExplorer();
-    void runCommand();
-    void initializeWallpaper();
 
 protected:
-    void drawBackground(QPainter *painter, const QRectF &);
-    void resizeEvent(QResizeEvent *event);
     void wheelEvent(QWheelEvent *event);
-    void contextMenuEvent(QContextMenuEvent *event);
 
 private:
-    Plasma::Svg *m_background;
-    QPixmap* m_bitmapBackground;
-    QString m_wallpaperPath;
-    QAction *m_engineExplorerAction;
-    QAction *m_runCommandAction;
     QAction *m_zoomInAction;
     QAction *m_zoomOutAction;
+    int m_screen;
     Plasma::ZoomLevel m_zoomLevel;
 };
 
