@@ -30,6 +30,7 @@
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <k3socketaddress.h>
+#include <kdebug.h>
 
 #include <solid/device.h>
 #include <solid/genericinterface.h>
@@ -1538,7 +1539,7 @@ bool SolidShell::bluetoothRemoteHasBonding(const QString &adapterUbi, const QStr
     {
         cout << "'" << deviceUbi << "' is bonded/paired." << endl;
     } else {
-        cout << "'" << deviceUbi << "' isn't bonded/paired." << endl;
+        cout << "'" << deviceUbi << "' is not bonded/paired." << endl;
     }
 
     return true;
